@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2022 Valve Corporation
- * Copyright (c) 2020-2022 LunarG, Inc.
+ * Copyright (c) 2020-2025 Valve Corporation
+ * Copyright (c) 2020-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +20,8 @@
 
 #include "doc.h"
 #include "setting_flags.h"
-#include "override.h"
+#include "configurator.h"
+#include "vulkan_util.h"
 
 #include <QFileInfo>
 
@@ -50,81 +51,78 @@ static std::string BuildPlatformsMarkdown(int platform_flags) {
     return text;
 }
 
-static void WriteSettingsOverviewHtml(std::string& text, const Layer& layer, const SettingMetaSet& settings) {
+static std::string GetTabs(std::size_t depth) {
+    std::string result;
+    for (std::size_t i = 0, n = depth; i < n; ++i) {
+        result += "&nbsp;&nbsp;&nbsp;&nbsp;";
+    }
+    return result;
+}
+
+static void WriteSettingsOverviewHtml(std::string& text, const Layer& layer, const SettingMetaSet& settings, std::size_t depth) {
     for (std::size_t i = 0, n = settings.size(); i < n; ++i) {
         const SettingMeta* setting = settings[i];
 
-        if (setting->type != SETTING_GROUP && setting->view != SETTING_VIEW_HIDDEN) {
+        if (setting->view == SETTING_VIEW_STANDARD) {
             text += "<tr>\n";
-            text += format("\t<td><a id=\"%s\"href=\"#%s-detailed\">%s</a></td>\n", setting->key.c_str(), setting->key.c_str(),
-                           setting->label.c_str());
-
+            text += format("\t<td>%s<a id=\"%s\" href=\"#%s-detailed\">%s</a></td>\n", ::GetTabs(depth).c_str(),
+                           setting->key.c_str(), setting->key.c_str(), setting->label.c_str());
+            text += format("\t<td><span class=\"code\">%s</span></td>\n", setting->key.c_str());
             text += format("\t<td><span class=\"code\">%s</span></td>\n", GetToken(setting->type));
             text += format("\t<td><span class=\"code\">%s</span></td>\n", setting->Export(EXPORT_MODE_DOC).c_str());
 
-            text +=
-                format("\t<td><span class=\"code\">%s</span></td>\n", (GetLayerSettingPrefix(layer.key) + setting->key).c_str());
-            if (setting->env.empty()) {
-                text += format("\t<td>N/A</td>\n", setting->env.c_str());
-            } else {
-                text += format("\t<td><span class=\"code\">%s</span></td>\n", setting->env.c_str());
-            }
-
             text += format("\t<td>%s</td>\n", BuildPlatformsHtml(setting->platform_flags).c_str());
+
             text += "</tr>\n";
         }
 
         if (IsEnum(setting->type) || IsFlags(setting->type)) {
             const SettingMetaEnumeration& setting_enum = static_cast<const SettingMetaEnumeration&>(*setting);
             for (std::size_t j = 0, o = setting_enum.enum_values.size(); j < o; ++j) {
-                WriteSettingsOverviewHtml(text, layer, setting_enum.enum_values[j].settings);
+                WriteSettingsOverviewHtml(text, layer, setting_enum.enum_values[j].settings, depth + 1);
             }
         }
 
-        WriteSettingsOverviewHtml(text, layer, setting->children);
+        WriteSettingsOverviewHtml(text, layer, setting->children, depth + 1);
     }
 }
 
-static void WriteSettingsOverviewMarkdown(std::string& text, const Layer& layer, const SettingMetaSet& settings) {
+std::string BuildArchor(const std::string& label) {
+    std::string tmp = ToLowerCase(label);
+    std::replace(tmp.begin(), tmp.end(), ' ', '-');
+    return tmp;
+}
+
+static void WriteSettingsOverviewMarkdown(std::string& text, const Layer& layer, const SettingMetaSet& settings,
+                                          std::size_t depth) {
     for (std::size_t i = 0, n = settings.size(); i < n; ++i) {
         const SettingMeta* setting = settings[i];
 
-        if (setting->type != SETTING_GROUP && setting->view != SETTING_VIEW_HIDDEN) {
-            text += "|" + setting->label + "|" + GetToken(setting->type) + "|";
-
-            text += setting->Export(EXPORT_MODE_DOC) + "|";
-
-            text += GetLayerSettingPrefix(layer.key) + setting->key + "|";
-
-            if (setting->env.empty()) {
-                text += "N/A";
-            } else {
-                text += setting->env;
-            }
-            text += "|";
-            text += BuildPlatformsMarkdown(setting->platform_flags) + "|\n";
+        if (setting->view == SETTING_VIEW_STANDARD) {
+            text += "| ";
+            text += ::GetTabs(depth) + "[" + setting->label + "](#" + ::BuildArchor(setting->label) + ") | ";
+            text += setting->key + " | ";
+            text += GetToken(setting->type) + std::string(" | ");
+            text += setting->Export(EXPORT_MODE_DOC) + " | ";
+            text += BuildPlatformsMarkdown(setting->platform_flags) + " |\n";
         }
 
         if (IsEnum(setting->type) || IsFlags(setting->type)) {
             const SettingMetaEnumeration& setting_enum = static_cast<const SettingMetaEnumeration&>(*setting);
             for (std::size_t j = 0, o = setting_enum.enum_values.size(); j < o; ++j) {
-                WriteSettingsOverviewMarkdown(text, layer, setting_enum.enum_values[j].settings);
+                WriteSettingsOverviewMarkdown(text, layer, setting_enum.enum_values[j].settings, depth + 1);
             }
         }
 
-        WriteSettingsOverviewMarkdown(text, layer, setting->children);
+        WriteSettingsOverviewMarkdown(text, layer, setting->children, depth + 1);
     }
 }
 
 static const std::string GetLayerSettingsDocURL(const Layer& layer) {
     if (layer.api_version >= Version(1, 3, 268)) {
-        return format("https://github.com/LunarG/VulkanTools/tree/sdk-%s.0/vkconfig#vulkan-layers-settings",
-                      layer.api_version.str().c_str());
-    } else if (layer.api_version > Version(1, 2, 182)) {
-        return format("https://github.com/LunarG/VulkanTools/tree/sdk-%s.0/vkconfig#vulkan-layers-settings",
-                      layer.api_version.str().c_str());
+        return format("https://vulkan.lunarg.com/doc/sdk/%s.0/windows/layer_configuration.html", layer.api_version.str().c_str());
     } else {
-        return "https://github.com/LunarG/VulkanTools/tree/main/vkconfig#vulkan-layers-settings";
+        return "https://vulkan.lunarg.com/doc/view/latest/windows/layer_configuration.html";
     }
 }
 
@@ -132,7 +130,7 @@ static void WriteSettingsDetailsHtml(std::string& text, const Layer& layer, cons
     for (std::size_t i = 0, n = settings.size(); i < n; ++i) {
         const SettingMeta* setting = settings[i];
 
-        if (setting->type != SETTING_GROUP && setting->view != SETTING_VIEW_HIDDEN) {
+        if (setting->view == SETTING_VIEW_STANDARD) {
             if (setting->status == STATUS_STABLE) {
                 text += format("<h3><a id=\"%s-detailed\" href=\"#%s\">%s</a></h3>\n", setting->key.c_str(), setting->key.c_str(),
                                setting->label.c_str());
@@ -143,26 +141,50 @@ static void WriteSettingsDetailsHtml(std::string& text, const Layer& layer, cons
 
             text += format("\t<p>%s</p>\n", setting->description.c_str());
 
-            text += "<h4>Setting Properties:</h4>\n";
+            if (setting->type != SETTING_GROUP) {
+                text += "<table>\n";
+                text += format("<thead><tr><th><a href=\"%s\">Settings Methods</a></th><th>Settings Variables</th></tr></thead>\n",
+                               GetLayerSettingsDocURL(layer).c_str());
+                text += "<tbody>\n";
+                text += format("\t<tr><td>VK_EXT_layer_settings variable:</td><td><span class=\"code\">%s</span></td></tr>\n",
+                               setting->key.c_str());
+                text += format("\t<tr><td>vk_layer_settings.txt variable:</td><td><span class=\"code\">%s</span></td></tr>\n",
+                               (GetLayerSettingPrefix(layer.key) + setting->key).c_str());
+
+                std::vector<std::string> envs = BuildEnvVariablesList(layer.key.c_str(), setting->key.c_str());
+                if (!setting->env.empty()) {
+                    envs.push_back(setting->env);
+                }
+                text += format("\t<tr><td>Environment variables:</td><td><span class=\"code\">%s</span></td></tr>\n",
+                               Merge(envs, "<BR/>").c_str());
+
+                if (setting->platform_flags & PLATFORM_ANDROID_BIT) {
+                    std::vector<std::string> commands = BuildEnvVariablesList(layer.key.c_str(), setting->key.c_str(), true);
+                    std::vector<std::string> list;
+
+                    for (std::size_t i = 0, n = commands.size(); i < n; ++i) {
+                        list.push_back(format("adb setprop %s", commands[i].c_str()));
+                    }
+
+                    if (!layer.prefix.empty()) {
+                        list.push_back(format("adb setprop debug.%s", (layer.prefix + "." + setting->key).c_str()));
+                    }
+
+                    text += format("\t<tr><td>Android system properties:</td><td><span class=\"code\">%s</span></td></tr>\n",
+                                   Merge(list, "<BR/>").c_str());
+                }
+
+                text += "</tbody></table>\n";
+            }
+
             text += "<ul>\n";
-            text += format("\t<li><a href=\"%s\">vk_layer_settings.txt</a> Variable: <span class=\"code\">%s</span></li>\n",
-                           GetLayerSettingsDocURL(layer).c_str(), (GetLayerSettingPrefix(layer.key) + setting->key).c_str());
-            if (setting->env.empty()) {
-                text += format("\t<li>Environment Variable: <span class=\"code\">%s</span></li>\n", "N/A");
-            } else {
-                text += format("\t<li>Environment Variable: <span class=\"code\">%s</span></li>\n", setting->env.c_str());
+
+            text += format("\t<li>Type: <span class=\"code\">%s</span></li>\n", GetToken(setting->type));
+            if (setting->type != SETTING_GROUP) {
+                text +=
+                    format("\t<li>Default Value: <span class=\"code\">%s</span></li>\n", setting->Export(EXPORT_MODE_DOC).c_str());
             }
             text += format("\t<li>Platforms: %s</li>\n", BuildPlatformsHtml(setting->platform_flags).c_str());
-
-            if (setting->view != SETTING_VIEW_STANDARD) {
-                text += format("\t<li>Setting Level: %s</li>\n", GetToken(setting->view));
-            }
-
-            text += format(
-                "\t<li>Setting Type: <span class=\"code\">%s</span></li>\n\t<li>Setting Default Value: <span "
-                "class=\"code\">%s</span></li>\n",
-                GetToken(setting->type), setting->Export(EXPORT_MODE_DOC).c_str());
-
             text += "</ul>\n";
 
             if (IsEnum(setting->type) || IsFlags(setting->type)) {
@@ -180,7 +202,9 @@ static void WriteSettingsDetailsHtml(std::string& text, const Layer& layer, cons
                     for (std::size_t j = 0, o = setting_enum.enum_values.size(); j < o; ++j) {
                         const SettingEnumValue& value = setting_enum.enum_values[j];
 
-                        if (value.view == SETTING_VIEW_HIDDEN) continue;
+                        if (value.view != SETTING_VIEW_STANDARD) {
+                            continue;
+                        }
 
                         text += "<tr>\n";
                         text += format("\t<td>%s</td>\n", value.key.c_str());
@@ -200,8 +224,49 @@ static void WriteSettingsDetailsHtml(std::string& text, const Layer& layer, cons
                     }
                 }
             }
+
+            if (!setting->dependence.empty()) {
+                text += "<h4>Setting Dependences</h4>\n";
+                if (setting->dependence.size() > 1) {
+                    switch (setting->dependence_mode) {
+                        case DEPENDENCE_NONE:
+                            // text += "\n";
+                            break;
+                        case DEPENDENCE_ALL:
+                            text += "<p>All the following condition must be fulfilled for the setting to be applied.</p>\n";
+                            break;
+                        case DEPENDENCE_ANY:
+                            text += "<p>Any of the following condition must be fulfilled for the setting to be applied.</p>\n";
+                            break;
+                    }
+                }
+
+                text += "<table><thead><tr>";
+                text += format("<th>Label</th><th><a href=\"%s\">Variables Key</a></th><th>Type</th><th>Value</th>",
+                               GetLayerSettingsDocURL(layer).c_str());
+                text += "</tr></thead><tbody>\n";
+
+                for (std::size_t i = 0, n = setting->dependence.size(); i < n; ++i) {
+                    const SettingMeta* setting_dep = ::FindSetting(layer.settings, setting->dependence[i]->key.c_str());
+                    if (setting_dep == nullptr) {
+                        continue;
+                    }
+
+                    text += "<tr>\n";
+                    text +=
+                        format("<td><a href=\"#%s-detailed\">%s</a></td>", setting_dep->key.c_str(), setting_dep->label.c_str());
+                    text += format("<td>%s</td>", setting_dep->key.c_str());
+                    text += format("<td>%s</td>", GetToken(setting_dep->type));
+                    text += format("<td>%s</td>", setting->dependence[i]->Export(EXPORT_MODE_DOC).c_str());
+                    text += "</tr>\n";
+                }
+
+                text += "</tbody></table>\n";
+            }
         }
 
+        text += "<hr>\n";
+
         WriteSettingsDetailsHtml(text, layer, setting->children);
     }
 }
@@ -210,31 +275,53 @@ static void WriteSettingsDetailsMarkdown(std::string& text, const Layer& layer,
     for (std::size_t i = 0, n = settings.size(); i < n; ++i) {
         const SettingMeta* setting = settings[i];
 
-        if (setting->type != SETTING_GROUP && setting->view != SETTING_VIEW_HIDDEN) {
+        if (setting->view == SETTING_VIEW_STANDARD) {
             if (setting->status == STATUS_STABLE) {
-                text += "#### " + setting->label;
+                text += "#### " + setting->label + "\n";
             } else {
-                text += "#### " + setting->label + "(" + GetToken(setting->status) + ")";
+                text += "#### " + setting->label + "(" + GetToken(setting->status) + ")\n";
             }
             text += "\n";
 
             text += setting->description + "\n";
 
-            text += "##### Setting Properties:\n";
-            text += "- vk_layer_settings.txt Variable: " + GetLayerSettingPrefix(layer.key) + setting->key + "\n";
-            if (setting->env.empty()) {
-                text += "- Environment Variable: N/A\n";
-            } else {
-                text += "- Environment Variable: " + setting->env + "\n";
+            if (setting->type != SETTING_GROUP) {
+                text += "\n";
+                text += "|Setting Methods|Setting Variables|\n";
+                text += "|---|---|\n";
+                text += "| VK_EXT_layer_settings variable: | " + setting->key + " |\n";
+                text += "| vk_layer_settings.txt variable: | " + GetLayerSettingPrefix(layer.key) + setting->key + " |\n";
+
+                std::vector<std::string> envs = BuildEnvVariablesList(layer.key.c_str(), setting->key.c_str());
+                if (!setting->env.empty()) {
+                    envs.push_back(setting->env);
+                }
+
+                for (std::size_t i = 0, n = envs.size(); i < n; ++i) {
+                    text += format("| %s | %s |\n", i == 0 ? "Environment variables:" : "", envs[i].c_str());
+                }
+
+                if (setting->platform_flags & PLATFORM_ANDROID_BIT) {
+                    std::vector<std::string> commands = BuildEnvVariablesList(layer.key.c_str(), setting->key.c_str(), true);
+
+                    for (std::size_t i = 0, n = commands.size(); i < n; ++i) {
+                        text +=
+                            format("| %s | adb setprop %s |\n", i == 0 ? "Android system properties :" : "", commands[i].c_str());
+                    }
+
+                    if (!layer.prefix.empty()) {
+                        text += format("|  | adb setprop debug.%s |\n", (layer.prefix + "." + setting->key).c_str());
+                    }
+                }
+                text += "\n";
+            }
+
+            text += format("- Type: %s\n", GetToken(setting->type));
+            if (setting->type != SETTING_GROUP) {
+                text += format("- Default Value: %s\n", setting->Export(EXPORT_MODE_DOC).c_str());
             }
             text += "- Platforms: " + BuildPlatformsMarkdown(setting->platform_flags) + "\n";
-
-            if (setting->view != SETTING_VIEW_STANDARD) {
-                text += format("- Setting Level: %s\n", GetToken(setting->view));
-            }
-
-            text += format("- Setting Type: %s\n- Setting Default Value: %s\n\n", GetToken(setting->type),
-                           setting->Export(EXPORT_MODE_DOC).c_str());
+            text += "\n";
 
             if (IsEnum(setting->type) || IsFlags(setting->type)) {
                 const SettingMetaEnumeration& setting_enum = static_cast<const SettingMetaEnumeration&>(*setting);
@@ -249,7 +336,9 @@ static void WriteSettingsDetailsMarkdown(std::string& text, const Layer& layer,
                     for (std::size_t j = 0, o = setting_enum.enum_values.size(); j < o; ++j) {
                         const SettingEnumValue& value = setting_enum.enum_values[j];
 
-                        if (value.view == SETTING_VIEW_HIDDEN) continue;
+                        if (value.view != SETTING_VIEW_STANDARD) {
+                            continue;
+                        }
 
                         text += "|" + value.key + "|" + value.label + "|";
                         if (value.description.empty()) {
@@ -264,24 +353,46 @@ static void WriteSettingsDetailsMarkdown(std::string& text, const Layer& layer,
                     }
                 }
             }
+
+            if (!setting->dependence.empty()) {
+                if (setting->dependence.size() > 1) {
+                    switch (setting->dependence_mode) {
+                        case DEPENDENCE_NONE:
+                            text += "\n";
+                            break;
+                        case DEPENDENCE_ALL:
+                            text += "All the following condition must be fulfilled for the setting to be applied.\n";
+                            break;
+                        case DEPENDENCE_ANY:
+                            text += "Any of the following condition must be fulfilled for the setting to be applied.\n";
+                            break;
+                    }
+                    text += "\n";
+                }
+
+                text += "| Dependences | Variables Key | Type | Value |\n";
+                text += "|---|---|---|---|\n";
+                for (std::size_t i = 0, n = setting->dependence.size(); i < n; ++i) {
+                    const SettingMeta* setting_dep = ::FindSetting(layer.settings, setting->dependence[i]->key.c_str());
+                    if (setting_dep == nullptr) {
+                        continue;
+                    }
+
+                    text += "| ";
+                    text += "[" + setting_dep->label + "](#" + ::BuildArchor(setting_dep->label) + ") | ";
+                    text += setting_dep->key + " | ";
+                    text += GetToken(setting_dep->type) + std::string(" | ");
+                    text += setting->dependence[i]->Export(EXPORT_MODE_DOC) + " |\n";
+                }
+                text += "\n";
+            }
         }
 
         WriteSettingsDetailsMarkdown(text, layer, setting->children);
     }
 }
 
-size_t GetNumSettings(const Layer& layer) {
-    std::size_t rval = layer.settings.size();
-    for (std::size_t i = 0, n = layer.settings.size(); i < n; ++i) {
-        const SettingMeta* setting = layer.settings[i];
-        if (setting->type != SETTING_GROUP && setting->view != SETTING_VIEW_HIDDEN) {
-            rval += setting->children.size();
-        }
-    }
-    return rval;
-}
-
-void ExportHtmlDoc(const Layer& layer, const std::string& path) {
+bool ExportHtmlDoc(const Layer& layer, const std::string& path) {
     std::string text;
 
     text += "<!DOCTYPE html>\n";
@@ -299,10 +410,10 @@ void ExportHtmlDoc(const Layer& layer, const std::string& path) {
     text += "</style>\n";
 
     text += "<h1 id=\"top\">";
-    if (layer.url.empty()) {
+    if (layer.url.Empty()) {
         text += format("%s\n", layer.key.c_str());
     } else {
-        text += format("<a href=\"%s\">%s</a>\n", layer.url.c_str(), layer.key.c_str());
+        text += format("<a href=\"%s\">%s</a>\n", layer.url.AbsolutePath(false).c_str(), layer.key.c_str());
     }
 
     if (layer.status != STATUS_STABLE) {
@@ -322,9 +433,10 @@ void ExportHtmlDoc(const Layer& layer, const std::string& path) {
     text += "<ul>\n";
     text += format("\t<li>API Version: %s</li>\n", layer.api_version.str().c_str());
     text += format("\t<li>Implementation Version: %s</li>\n", layer.implementation_version.c_str());
-    text += format("\t<li>Layer Manifest: %s<ul>\n", QFileInfo(layer.manifest_path.c_str()).fileName().toStdString().c_str());
+    text += format("\t<li>Layer Manifest: %s<ul>\n",
+                   QFileInfo(layer.manifest_path.RelativePath().c_str()).fileName().toStdString().c_str());
     text += format("\t\t<li>File Format: %s</li>\n", layer.file_format_version.str().c_str());
-    text += format("\t\t<li>Layer Binary Path: %s</li>\n", layer.binary_path.c_str());
+    text += format("\t\t<li>Layer Binary Path: %s</li>\n", layer.binary_path.RelativePath().c_str());
     text += "\t</ul></li>\n";
     if (layer.platforms != 0) {
         text += format("\t<li>Platforms: %s</li>\n", BuildPlatformsHtml(layer.platforms).c_str());
@@ -333,7 +445,8 @@ void ExportHtmlDoc(const Layer& layer, const std::string& path) {
         text += format("\t<li>Status: %s</li>\n", GetToken(layer.status));
     }
     if (!layer.settings.empty()) {
-        text += format("\t<li><a href=\"#settings\">Number of Layer Settings: %d</a></li>\n", GetNumSettings(layer));
+        text +=
+            format("\t<li><a href=\"#settings\">Number of Layer Settings: %d</a></li>\n", ::CountSettings(layer.settings, true));
     }
     if (!layer.presets.empty()) {
         text += format("\t<li><a href=\"#presets\">Number of Layer Presets: %d</a></li>\n", layer.presets.size());
@@ -343,12 +456,11 @@ void ExportHtmlDoc(const Layer& layer, const std::string& path) {
     if (!layer.settings.empty()) {
         text += "<h2><a id=\"settings\">Layer Settings Overview</a></h2>\n";
         text += "<table><thead><tr>";
-        text += format(
-            "<th>Setting</th><th>Type</th><th>Default Value</th><th><a href=\"%s\">vk_layer_settings.txt</a> Variable</th>"
-            "<th>Environment Variable</th><th>Platforms</th>",
-            GetLayerSettingsDocURL(layer).c_str());
+        text +=
+            format("<th>Label</th><th><a href=\"%s\">Variables Key</a></th><th>Type</th><th>Default Value</th><th>Platforms</th>",
+                   GetLayerSettingsDocURL(layer).c_str());
         text += "</tr></thead><tbody>\n";
-        WriteSettingsOverviewHtml(text, layer, layer.settings);
+        WriteSettingsOverviewHtml(text, layer, layer.settings, 0);
         text += "</tbody></table>\n";
 
         text += "<h2>Layer Settings Details</h2>\n";
@@ -385,32 +497,45 @@ void ExportHtmlDoc(const Layer& layer, const std::string& path) {
     if (file.open(QIODevice::WriteOnly | QIODevice::Text)) {
         file.write(text.c_str());
         file.close();
-        printf("vkconfig: html file written to %s\n", path.c_str());
+        printf("vkconfig: HTML file written to %s\n", path.c_str());
+        return true;
     } else {
         printf("vkconfig: could not write %s\n", path.c_str());
+        return false;
     }
 }
 
-void ExportMarkdownDoc(const Layer& layer, const std::string& path) {
+bool ExportMarkdownDoc(const Layer& layer, const std::string& path) {
     std::string text;
 
     text += format("## %s\n", layer.key.c_str());
+    text += "\n";
 
     if (!layer.description.empty()) {
         text += "### " + layer.description + "\n";
+        text += "\n";
     }
 
     if (!layer.introduction.empty()) {
         text += layer.introduction + "\n";
+        text += "\n";
     }
 
-    text += "### Layer Properties\n\n";
+    text += "### Layer Properties\n";
+    text += "\n";
     text += "- API Version: " + layer.api_version.str() + "\n";
     text += "- Implementation Version: " + layer.implementation_version + "\n";
-    text += "- Layer Manifest: " + QFileInfo(layer.manifest_path.c_str()).fileName().toStdString() + "\n";
+    text += "- Layer Manifest: " + QFileInfo(layer.manifest_path.RelativePath().c_str()).fileName().toStdString() + "\n";
     text += "  - File Format: " + layer.file_format_version.str() + "\n";
     text += "  - Layer Binary: ";
-    text += (layer.binary_path.rfind("./", 0) == 0 ? layer.binary_path.substr(2) : layer.binary_path) + "\n";
+    text += (layer.binary_path.RelativePath().rfind("./", 0) == 0 ? layer.binary_path.RelativePath().substr(2)
+                                                                  : layer.binary_path.RelativePath()) +
+            "\n";
+    text += "- Variables:\n";
+    text += format("  - vk_layer_settings.txt namespace: %s\n", ToLowerCase(TrimPrefix(layer.key)).c_str());
+    text += format("  - Environment Variable prefix: VK_%s_\n", ToUpperCase(TrimPrefix(layer.key)).c_str());
+    text +=
+        format("  - Android system property prefix: adb setprop debug.vulkan.%s.\n", ToLowerCase(TrimPrefix(layer.key)).c_str());
 
     if (layer.platforms != 0) {
         text += "- Platforms: " + BuildPlatformsMarkdown(layer.platforms) + "\n";
@@ -419,7 +544,7 @@ void ExportMarkdownDoc(const Layer& layer, const std::string& path) {
         text += format(" - Status: %s\n", GetToken(layer.status));
     }
     if (!layer.settings.empty()) {
-        text += format("- Number of Layer Settings: %d\n", layer.settings.size());
+        text += format("- Number of Layer Settings: %d\n", ::CountSettings(layer.settings, true));
     }
     if (!layer.presets.empty()) {
         text += format("- Number of Layer Presets: %d\n", layer.presets.size());
@@ -428,21 +553,27 @@ void ExportMarkdownDoc(const Layer& layer, const std::string& path) {
 
     if (!layer.settings.empty()) {
         text += "### Layer Settings Overview\n";
-        text += "|Setting|Type|Default Value|vk_layer_settings.txt Variable|Environment Variable|Platforms|\n";
-        text += "|---|---|---|---|---|---|\n";
-        WriteSettingsOverviewMarkdown(text, layer, layer.settings);
+        text += "\n";
+        text += "|Label|Variables Key|Type|Default Value|Platforms|\n";
+        text += "|---|---|---|---|---|\n";
+        WriteSettingsOverviewMarkdown(text, layer, layer.settings, 0);
+        text += "\n";
 
         text += "### Layer Settings Details\n";
+        text += "\n";
         WriteSettingsDetailsMarkdown(text, layer, layer.settings);
     }
 
     if (!layer.presets.empty()) {
         text += "### Layer Presets\n";
+        text += "\n";
         for (std::size_t i = 0, n = layer.presets.size(); i < n; ++i) {
             const LayerPreset& preset = layer.presets[i];
 
             text += "#### " + preset.label + "\n";
+            text += "\n";
             text += preset.description + "\n";
+            text += "\n";
             text += "##### Preset Setting Values:\n";
             for (std::size_t j = 0, o = preset.settings.size(); j < o; ++j) {
                 const SettingData* data = preset.settings[j];
@@ -450,6 +581,7 @@ void ExportMarkdownDoc(const Layer& layer, const std::string& path) {
 
                 text += "- " + meta->label + ": " + data->Export(EXPORT_MODE_DOC).c_str() + "\n";
             }
+            text += "\n";
         }
     }
 
@@ -458,14 +590,21 @@ void ExportMarkdownDoc(const Layer& layer, const std::string& path) {
         file.write(text.c_str());
         file.close();
         printf("vkconfig: markdown file written to %s\n", path.c_str());
+        return true;
     } else {
         printf("vkconfig: could not write %s\n", path.c_str());
+        return false;
     }
 }
 
-void ExportSettingsDoc(const std::vector<Layer>& available_layers, const Configuration& configuration, const std::string& path) {
-    if (WriteLayersSettings(available_layers, configuration, path))
+bool ExportSettingsDoc(Configurator& configurator, const std::string& path) {
+    const bool result = configurator.WriteLayersSettings(OVERRIDE_AREA_LAYERS_SETTINGS_BIT, path);
+
+    if (result)
         printf("vkconfig: settings written to %s\n", path.c_str());
-    else
+    else {
         printf("vkconfig: could not write %s\n", path.c_str());
+    }
+
+    return result;
 }
