@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2022 Valve Corporation
- * Copyright (c) 2020-2022 LunarG, Inc.
+ * Copyright (c) 2020-2025 Valve Corporation
+ * Copyright (c) 2020-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,60 +29,44 @@
 #include "setting_int.h"
 #include "setting_list.h"
 #include "setting_string.h"
-#include "platform.h"
+#include "type_platform.h"
 #include "util.h"
 #include "path.h"
 #include "json.h"
 #include "json_validator.h"
-#include "alert.h"
+#include "is_dll_32.h"
+#include "configurator.h"
 
 #include <QFile>
 #include <QDir>
 #include <QMessageBox>
 #include <QJsonArray>
-#include <QSettings>
 #include <QDateTime>
+#include <QCheckBox>
+#include <QDesktopServices>
+#include <QFileDialog>
 
 #include <cassert>
 #include <string>
 #include <algorithm>
 
-static std::string GetBuiltinFolder(const Version& version) {
-    QDir dir(":/layers");
-    dir.setFilter(QDir::Dirs);
-    QFileInfoList list = dir.entryInfoList();
+bool operator<(const LayersPathInfo& a, const LayersPathInfo& b) { return a.path.RelativePath() < b.path.RelativePath(); }
 
-    std::vector<int> version_supported;
-
-    for (int i = 0, n = list.size(); i < n; ++i) {
-        const std::string value = list[i].baseName().toStdString();
-        if (!IsNumber(value)) continue;
-        version_supported.push_back(std::atoi(value.c_str()));
+bool Found(const std::vector<LayersPathInfo>& data, const Path& path) {
+    for (std::size_t i = 0, n = data.size(); i < n; ++i) {
+        if (data[i].path == path) {
+            return true;
+        }
     }
 
-    std::sort(version_supported.begin(), version_supported.end());
-
-    const int searched_version = version.GetPatch();
-
-    for (int i = static_cast<int>(version_supported.size()) - 1; i >= 0; --i) {
-        const int current_version = version_supported[i];
-
-        if (searched_version < current_version) continue;
-
-        return format(":/layers/%d", current_version);
-    }
-
-    return ":/layers/170";
+    return false;
 }
 
-const char* Layer::NO_PRESET = "User-Defined Settings";
+Layer::Layer() : status(STATUS_STABLE), platforms(PLATFORM_DESKTOP_BIT) {}
 
-Layer::Layer() : status(STATUS_STABLE), platforms(PLATFORM_DESKTOP_BIT), type(LAYER_TYPE_EXPLICIT) {}
+Layer::Layer(const std::string& key) : key(key), status(STATUS_STABLE), platforms(PLATFORM_DESKTOP_BIT) {}
 
-Layer::Layer(const std::string& key, const LayerType layer_type)
-    : key(key), status(STATUS_STABLE), platforms(PLATFORM_DESKTOP_BIT), type(layer_type) {}
-
-Layer::Layer(const std::string& key, const LayerType layer_type, const Version& file_format_version, const Version& api_version,
+Layer::Layer(const std::string& key, const Version& file_format_version, const Version& api_version,
              const std::string& implementation_version, const std::string& library_path)
     : key(key),
       file_format_version(file_format_version),
@@ -90,18 +74,64 @@ Layer::Layer(const std::string& key, const LayerType layer_type, const Version&
       api_version(api_version),
       implementation_version(implementation_version),
       status(STATUS_STABLE),
-      platforms(PLATFORM_DESKTOP_BIT),
-      type(layer_type) {}
+      platforms(PLATFORM_DESKTOP_BIT) {}
 
-// Todo: Load the layer with Vulkan API
 bool Layer::IsValid() const {
-    return file_format_version != Version::VERSION_NULL && !key.empty() && !binary_path.empty() &&
-           api_version != Version::VERSION_NULL && !implementation_version.empty();
+    return file_format_version != Version::NONE && !key.empty() && !binary_path.Empty() && api_version != Version::NONE &&
+           !implementation_version.empty();
 }
 
-std::string Layer::FindPresetLabel(const SettingDataSet& settings) const {
+LayerControl Layer::GetActualControl() const {
+    if (this->type == LAYER_TYPE_IMPLICIT) {
+        if (!this->disable_env.empty()) {
+            if (qEnvironmentVariableIsSet(this->disable_env.c_str())) {
+                return LAYER_CONTROL_OFF;
+            }
+        }
+
+        if (!this->enable_env.empty()) {
+            if (qgetenv(this->enable_env.c_str()).toStdString() == this->enable_value) {
+                return LAYER_CONTROL_ON;
+            } else {
+                return LAYER_CONTROL_OFF;  // Implicit layer which has an enable env must have it set to be enabled
+            }
+        }
+
+        return LAYER_CONTROL_ON;  // Implicit layer
+    } else {
+        return LAYER_CONTROL_OFF;  // Explicit layer
+    }
+}
+
+std::string Layer::GetActualControlTooltip() const {
+    if (this->type == LAYER_TYPE_IMPLICIT) {
+        if (!this->disable_env.empty()) {
+            if (qEnvironmentVariableIsSet(this->disable_env.c_str())) {
+                return format("'%s' is set", this->disable_env.c_str());
+            }
+        }
+
+        if (!this->enable_env.empty()) {
+            const std::string& value = qgetenv(this->enable_env.c_str()).toStdString();
+            if (value == this->enable_value) {
+                return format("'%s' is set to '%s'.", this->enable_env.c_str(), value.c_str());
+            } else {
+                return format("Set '%s' to '%s' to enable '%s' by default.", this->enable_env.c_str(), this->enable_value.c_str(),
+                              this->key.c_str());
+            }
+        }
+
+        return format("Set '%s' to disable '%s' by default.", this->disable_env.c_str(), this->key.c_str());
+    } else {
+        return ::GetDescription(LAYER_CONTROL_AUTO);
+    }
+}
+
+int Layer::FindPresetIndex(const SettingDataSet& settings) const {
     for (std::size_t i = 0, n = this->presets.size(); i < n; ++i) {
-        if (HasPreset(settings, this->presets[i].settings)) return this->presets[i].label;
+        if (::HasPreset(settings, this->presets[i].settings)) {
+            return static_cast<int>(i);
+        }
     }
 
     return NO_PRESET;
@@ -164,80 +194,133 @@ SettingMeta* Layer::Instantiate(SettingMetaSet& meta_set, const std::string& key
     return setting_meta;
 }
 
-bool Layer::Load(const std::vector<Layer>& available_layers, const std::string& full_path_to_file, LayerType layer_type) {
-    this->type = layer_type;  // Set layer type, no way to know this from the json file
+LayerLoadStatus Layer::Load(const Path& full_path_to_file, LayerType type, bool request_validate_manifest,
+                            const std::map<Path, LayerStatus>& layers_found, ConfiguratorMode configurator_mode) {
+    this->type = type;  // Set layer type, no way to know this from the json file
 
-    if (full_path_to_file.empty()) return false;
+    if (full_path_to_file.Empty()) {
+        return LAYER_LOAD_IGNORED;
+    }
 
-    QFile file(full_path_to_file.c_str());
+    QFile file(full_path_to_file.AbsolutePath().c_str());
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        return false;
+        return LAYER_LOAD_FAILED;
     }
 
     QString json_text = file.readAll();
     file.close();
 
     this->manifest_path = full_path_to_file;
+    this->last_modified = full_path_to_file.LastModified();
+
+    auto it = layers_found.find(full_path_to_file.AbsolutePath().c_str());
+    if (it != layers_found.end()) {
+        if (it->second.disabled && it->second.last_modified == this->last_modified) {
+            return LAYER_LOAD_FAILED;
+        }
+    }
 
     // Convert the text to a JSON document & validate it.
     // It does need to be a valid json formatted file.
     QJsonParseError json_parse_error;
     const QJsonDocument& json_document = QJsonDocument::fromJson(json_text.toUtf8(), &json_parse_error);
     if (json_parse_error.error != QJsonParseError::NoError) {
-        return false;
+        return LAYER_LOAD_FAILED;
     }
 
     // Make sure it's not empty
     if (json_document.isNull() || json_document.isEmpty()) {
-        return false;
+        return LAYER_LOAD_FAILED;
     }
 
     // First check it's a layer manifest, ignore otherwise.
     const QJsonObject& json_root_object = json_document.object();
     if (json_root_object.value("file_format_version") == QJsonValue::Undefined) {
-        return false;  // Not a layer JSON file
+        return LAYER_LOAD_IGNORED;  // Not a layer JSON file
     }
     if (json_root_object.value("layer") == QJsonValue::Undefined) {
-        return false;  // Not a layer JSON file
+        return LAYER_LOAD_IGNORED;  // Not a layer JSON file
     }
 
     this->file_format_version = ReadVersionValue(json_root_object, "file_format_version");
     if (this->file_format_version.GetMajor() > 1) {
-        Alert::LayerInvalid(full_path_to_file.c_str(),
-                            format("Unsupported layer file format: %s", this->file_format_version.str().c_str()).c_str());
-        return false;
+        switch (configurator_mode) {
+            default: {
+            } break;
+            case CONFIGURATOR_MODE_GUI: {
+                QMessageBox alert;
+                alert.setWindowTitle("Failed to load a layer manifest...");
+                alert.setText(format("Unsupported layer file format: %s.", this->file_format_version.str().c_str()).c_str());
+                alert.setInformativeText(
+                    format("The %s layer is being ignored.", full_path_to_file.AbsolutePath().c_str()).c_str());
+                alert.setIcon(QMessageBox::Critical);
+                alert.exec();
+            } break;
+            case CONFIGURATOR_MODE_CMD: {
+                fprintf(stderr, "vkconfig: [ERROR] Unsupported layer file format: %s\n", this->file_format_version.str().c_str());
+                fprintf(stderr, "\n  (%s layer is ignored\n)", full_path_to_file.AbsolutePath().c_str());
+            } break;
+        }
+        return LAYER_LOAD_INVALID;
     }
 
     const QJsonObject& json_layer_object = ReadObject(json_root_object, "layer");
 
-    std::string current_last_modified = QFileInfo(full_path_to_file.c_str()).lastModified().toString(Qt::ISODate).toStdString();
-
-    QSettings settings;
-    std::string cached_last_modified = settings.value(full_path_to_file.c_str()).toString().toStdString();
-
     this->key = ReadStringValue(json_layer_object, "name");
 
     if (this->key == "VK_LAYER_LUNARG_override") {
-        return false;
-    }
-
-    // Check if a layer with the same name is already in the list
-    if (FindByKey(available_layers, this->key.c_str()) != nullptr) {
-        return false;
+        return LAYER_LOAD_IGNORED;
     }
 
     this->api_version = ReadVersionValue(json_layer_object, "api_version");
 
-    const bool is_builtin_layer_file =
-        full_path_to_file.rfind(":/") == 0;  // Check whether the path start with ":/" for resource file paths.
-
     JsonValidator validator;
 
-    const bool should_validate = current_last_modified != cached_last_modified;
+    std::string cached_last_modified;
+    if (it != layers_found.end()) {
+        cached_last_modified = it->second.last_modified;
+    }
+    const bool should_validate = request_validate_manifest && ((last_modified != cached_last_modified) || !it->second.validated);
     const bool is_valid = should_validate ? validator.Check(json_text) : true;
 
-    if (should_validate && is_valid) {
-        settings.setValue(full_path_to_file.c_str(), current_last_modified.c_str());
+    if (!is_valid) {
+        switch (configurator_mode) {
+            default: {
+            } break;
+            case CONFIGURATOR_MODE_GUI: {
+                QMessageBox alert;
+                alert.setWindowTitle("Failed to load a layer manifest...");
+                alert.setText(format("%s is not a valid layer file", full_path_to_file.AbsolutePath().c_str()).c_str());
+                alert.setInformativeText("Do you want to save the validation log?");
+                alert.setIcon(QMessageBox::Critical);
+                alert.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+                alert.setDefaultButton(QMessageBox::Yes);
+                int result = alert.exec();
+                if (result == QMessageBox::Yes) {
+                    const QString& selected_path = QFileDialog::getSaveFileName(
+                        nullptr, format("Export %s validation log", full_path_to_file.AbsolutePath().c_str()).c_str(),
+                        (AbsolutePath(Path::HOME) + "/" + full_path_to_file.Basename() + "_log.txt").c_str(), "Log(*.txt)");
+                    QFile log_file(selected_path);
+                    const bool result = log_file.open(QIODevice::WriteOnly | QIODevice::Text);
+                    if (result) {
+                        QDesktopServices::openUrl(QUrl::fromLocalFile(selected_path));
+                        log_file.write(validator.message.toStdString().c_str());
+                        log_file.close();
+                    } else {
+                        QMessageBox alert;
+                        alert.setWindowTitle("Failed to save layer manifest log...");
+                        alert.setText(format("Couldn't not open %s file...", selected_path.toStdString().c_str()).c_str());
+                        alert.setIcon(QMessageBox::Critical);
+                        alert.exec();
+                    }
+                }
+            } break;
+            case CONFIGURATOR_MODE_CMD: {
+                fprintf(stderr, "vkconfig: [ERROR] Couldn't validate layer file: %s\n", full_path_to_file.AbsolutePath().c_str());
+                fprintf(stderr, "\n%s\n)", validator.message.toStdString().c_str());
+            } break;
+        }
+        return LAYER_LOAD_INVALID;
     }
 
     const QJsonValue& json_library_path_value = json_layer_object.value("library_path");
@@ -245,6 +328,15 @@ bool Layer::Load(const std::vector<Layer>& available_layers, const std::string&
         this->binary_path = json_library_path_value.toString().toStdString();
     }
 
+    const Path& binary = this->manifest_path.AbsoluteDir() + "/" + this->binary_path.AbsolutePath();
+    if (::IsDLL32Bit(binary.AbsolutePath())) {
+        this->is_32bits = true;
+        return LAYER_LOAD_INVALID;
+    }
+
+    if (json_layer_object.value("prefix") != QJsonValue::Undefined) {
+        this->prefix = ReadStringValue(json_layer_object, "prefix");
+    }
     this->implementation_version = ReadStringValue(json_layer_object, "implementation_version");
     if (json_layer_object.value("status") != QJsonValue::Undefined) {
         this->status = GetStatusType(ReadStringValue(json_layer_object, "status").c_str());
@@ -257,27 +349,19 @@ bool Layer::Load(const std::vector<Layer>& available_layers, const std::string&
         this->introduction = ReadStringValue(json_layer_object, "introduction");
     }
     if (json_layer_object.value("url") != QJsonValue::Undefined) {
-        this->url = ReadStringValue(json_layer_object, "url");
+        this->url = Path(ReadStringValue(json_layer_object, "url"), false);
     }
 
     if (json_layer_object.value("disable_environment") != QJsonValue::Undefined) {
         const QJsonObject& json_env_object = json_layer_object.value("disable_environment").toObject();
         const QStringList keys = json_env_object.keys();
         this->disable_env = keys[0].toStdString();
-        this->disable_value = ReadStringValue(json_env_object, this->disable_env.c_str()) == "1";
     }
     if (json_layer_object.value("enable_environment") != QJsonValue::Undefined) {
         const QJsonObject& json_env_object = json_layer_object.value("enable_environment").toObject();
         const QStringList keys = json_env_object.keys();
         this->enable_env = keys[0].toStdString();
-        this->enable_value = ReadStringValue(json_env_object, this->enable_env.c_str()) == "1";
-    }
-
-    if (!is_valid && this->key != "VK_LAYER_LUNARG_override") {
-        if (!is_builtin_layer_file || (is_builtin_layer_file && this->api_version >= Version(1, 2, 170))) {
-            Alert::LayerInvalid(full_path_to_file.c_str(), validator.message.toStdString().c_str());
-            return false;
-        }
+        this->enable_value = ReadStringValue(json_env_object, this->enable_env.c_str());
     }
 
     const QJsonValue& json_features_value = json_layer_object.value("features");
@@ -285,12 +369,14 @@ bool Layer::Load(const std::vector<Layer>& available_layers, const std::string&
         const QJsonObject& json_features_object = json_features_value.toObject();
 
         // Load layer settings
+        this->settings.clear();
         const QJsonValue& json_settings_value = json_features_object.value("settings");
         if (json_settings_value != QJsonValue::Undefined) {
-            AddSettingsSet(this->settings, nullptr, json_settings_value);
+            this->AddSettingsSet(this->settings, nullptr, json_settings_value);
         }
 
         // Load layer presets
+        this->presets.clear();
         const QJsonValue& json_presets_value = json_features_object.value("presets");
         if (json_presets_value != QJsonValue::Undefined) {
             assert(json_presets_value.isArray());
@@ -300,13 +386,12 @@ bool Layer::Load(const std::vector<Layer>& available_layers, const std::string&
 
                 LayerPreset preset;
                 preset.platform_flags = this->platforms;
-                preset.status = this->status;
-                LoadMetaHeader(preset, json_preset_object);
+                ::LoadMetaHeader(preset, json_preset_object);
 
                 const QJsonArray& json_setting_array = ReadArray(json_preset_object, "settings");
                 for (int setting_index = 0, setting_count = json_setting_array.size(); setting_index < setting_count;
                      ++setting_index) {
-                    AddSettingData((SettingDataSet&)preset.settings, json_setting_array[setting_index]);
+                    this->AddSettingData((SettingDataSet&)preset.settings, json_setting_array[setting_index]);
                 }
 
                 this->presets.push_back(preset);
@@ -314,194 +399,25 @@ bool Layer::Load(const std::vector<Layer>& available_layers, const std::string&
         }
     }
 
-    // Override old built-in layer settings
-    if (!is_builtin_layer_file && this->api_version <= Version(1, 2, 176)) {
-        const std::string path = GetBuiltinFolder(this->api_version) + "/" + this->key + ".json";
-
-        Layer default_layer;
-        if (default_layer.Load(available_layers, path, this->type)) {
-            this->introduction = default_layer.introduction;
-            this->url = default_layer.url;
-            this->platforms = default_layer.platforms;
-            this->status = default_layer.status;
-            std::swap(this->settings, default_layer.settings);
-            std::swap(this->presets, default_layer.presets);
-            this->memory = default_layer.memory;
-        }
-    }
-
-    return this->IsValid();  // Not all JSON file are layer JSON valid
-}
-
-bool Layer::Load(const std::string& full_path_to_file, LayerType layer_type) {
-    this->type = layer_type;  // Set layer type, no way to know this from the json file
-
-    if (full_path_to_file.empty()) return false;
-
-    QFile file(full_path_to_file.c_str());
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        return false;
-    }
-
-    QString json_text = file.readAll();
-    file.close();
-
-    this->manifest_path = full_path_to_file;
-
-    // Convert the text to a JSON document & validate it.
-    // It does need to be a valid json formatted file.
-    QJsonParseError json_parse_error;
-    const QJsonDocument& json_document = QJsonDocument::fromJson(json_text.toUtf8(), &json_parse_error);
-    if (json_parse_error.error != QJsonParseError::NoError) {
-        return false;
-    }
-
-    // Make sure it's not empty
-    if (json_document.isNull() || json_document.isEmpty()) {
-        return false;
-    }
-
-    // First check it's a layer manifest, ignore otherwise.
-    const QJsonObject& json_root_object = json_document.object();
-    if (json_root_object.value("file_format_version") == QJsonValue::Undefined) {
-        return false;  // Not a layer JSON file
-    }
-    if (json_root_object.value("layer") == QJsonValue::Undefined) {
-        return false;  // Not a layer JSON file
-    }
-
-    this->file_format_version = ReadVersionValue(json_root_object, "file_format_version");
-    if (this->file_format_version.GetMajor() > 1) {
-        Alert::LayerInvalid(full_path_to_file.c_str(),
-                            format("Unsupported layer file format: %s", this->file_format_version.str().c_str()).c_str());
-        return false;
-    }
-
-    const QJsonObject& json_layer_object = ReadObject(json_root_object, "layer");
-
-    std::string current_last_modified = QFileInfo(full_path_to_file.c_str()).lastModified().toString(Qt::ISODate).toStdString();
-
-    QSettings settings;
-    std::string cached_last_modified = settings.value(full_path_to_file.c_str()).toString().toStdString();
-
-    this->key = ReadStringValue(json_layer_object, "name");
-
-    if (this->key == "VK_LAYER_LUNARG_override") {
-        return false;
-    }
-
-    this->api_version = ReadVersionValue(json_layer_object, "api_version");
-
-    const bool is_builtin_layer_file =
-        full_path_to_file.rfind(":/") == 0;  // Check whether the path start with ":/" for resource file paths.
-
-    JsonValidator validator;
-
-    const bool should_validate = current_last_modified != cached_last_modified;
-    const bool is_valid = should_validate ? validator.Check(json_text) : true;
-
-    if (should_validate && is_valid) {
-        settings.setValue(full_path_to_file.c_str(), current_last_modified.c_str());
-    }
-
-    const QJsonValue& json_library_path_value = json_layer_object.value("library_path");
-    if (json_library_path_value != QJsonValue::Undefined) {
-        this->binary_path = json_library_path_value.toString().toStdString();
-    }
-
-    this->implementation_version = ReadStringValue(json_layer_object, "implementation_version");
-    if (json_layer_object.value("status") != QJsonValue::Undefined) {
-        this->status = GetStatusType(ReadStringValue(json_layer_object, "status").c_str());
-    }
-    if (json_layer_object.value("platforms") != QJsonValue::Undefined) {
-        this->platforms = GetPlatformFlags(ReadStringArray(json_layer_object, "platforms"));
-    }
-    this->description = ReadStringValue(json_layer_object, "description");
-    if (json_layer_object.value("introduction") != QJsonValue::Undefined) {
-        this->introduction = ReadStringValue(json_layer_object, "introduction");
-    }
-    if (json_layer_object.value("url") != QJsonValue::Undefined) {
-        this->url = ReadStringValue(json_layer_object, "url");
-    }
-
-    if (json_layer_object.value("disable_environment") != QJsonValue::Undefined) {
-        const QJsonObject& json_env_object = json_layer_object.value("disable_environment").toObject();
-        const QStringList keys = json_env_object.keys();
-        this->disable_env = keys[0].toStdString();
-        this->disable_value = ReadStringValue(json_env_object, this->disable_env.c_str()) == "1";
-    }
-    if (json_layer_object.value("enable_environment") != QJsonValue::Undefined) {
-        const QJsonObject& json_env_object = json_layer_object.value("enable_environment").toObject();
-        const QStringList keys = json_env_object.keys();
-        this->enable_env = keys[0].toStdString();
-        this->enable_value = ReadStringValue(json_env_object, this->enable_env.c_str()) == "1";
-    }
-
-    if (!is_valid && this->key != "VK_LAYER_LUNARG_override") {
-        if (!is_builtin_layer_file || (is_builtin_layer_file && this->api_version >= Version(1, 2, 170))) {
-            Alert::LayerInvalid(full_path_to_file.c_str(), validator.message.toStdString().c_str());
-            return false;
-        }
-    }
-
-    const QJsonValue& json_features_value = json_layer_object.value("features");
-    if (json_features_value != QJsonValue::Undefined) {
-        const QJsonObject& json_features_object = json_features_value.toObject();
-
-        // Load layer settings
-        const QJsonValue& json_settings_value = json_features_object.value("settings");
-        if (json_settings_value != QJsonValue::Undefined) {
-            AddSettingsSet(this->settings, nullptr, json_settings_value);
-        }
-
-        // Load layer presets
-        const QJsonValue& json_presets_value = json_features_object.value("presets");
-        if (json_presets_value != QJsonValue::Undefined) {
-            assert(json_presets_value.isArray());
-            const QJsonArray& json_preset_array = json_presets_value.toArray();
-            for (int preset_index = 0, preset_count = json_preset_array.size(); preset_index < preset_count; ++preset_index) {
-                const QJsonObject& json_preset_object = json_preset_array[preset_index].toObject();
-
-                LayerPreset preset;
-                preset.platform_flags = this->platforms;
-                preset.status = this->status;
-                LoadMetaHeader(preset, json_preset_object);
-
-                const QJsonArray& json_setting_array = ReadArray(json_preset_object, "settings");
-                for (int setting_index = 0, setting_count = json_setting_array.size(); setting_index < setting_count;
-                     ++setting_index) {
-                    AddSettingData((SettingDataSet&)preset.settings, json_setting_array[setting_index]);
-                }
-
-                this->presets.push_back(preset);
-            }
-        }
-    }
-
-    // Override old built-in layer settings
-    if (!is_builtin_layer_file && this->api_version <= Version(1, 2, 176)) {
-        const std::string path = GetBuiltinFolder(this->api_version) + "/" + this->key + ".json";
-
-        Layer default_layer;
-        if (default_layer.Load(path, this->type)) {
-            this->introduction = default_layer.introduction;
-            this->url = default_layer.url;
-            this->platforms = default_layer.platforms;
-            this->status = default_layer.status;
-            std::swap(this->settings, default_layer.settings);
-            std::swap(this->presets, default_layer.presets);
-            this->memory = default_layer.memory;
-        }
-    }
-
-    return this->IsValid();  // Not all JSON file are layer JSON valid
+    return this->IsValid() ? LAYER_LOAD_ADDED : LAYER_LOAD_INVALID;  // Not all JSON file are layer JSON valid
 }
 
 void CollectDefaultSettingData(const SettingMetaSet& meta_set, SettingDataSet& data_set) {
     for (std::size_t i = 0, n = meta_set.size(); i < n; ++i) {
         SettingMeta* setting_meta = meta_set[i];
-        SettingData* setting_data = setting_meta->Instantiate();
-        data_set.push_back(setting_data);
+
+        bool setting_found = false;
+        for (auto it = data_set.begin(), end = data_set.end(); it != end; ++it) {
+            if ((*it)->key == setting_meta->key) {
+                setting_found = true;
+                break;
+            }
+        }
+
+        if (!setting_found) {
+            SettingData* setting_data = setting_meta->Instantiate();
+            data_set.push_back(setting_data);
+        }
 
         CollectDefaultSettingData(setting_meta->children, data_set);
 
@@ -521,12 +437,35 @@ void Layer::AddSettingsSet(SettingMetaSet& settings, const SettingMeta* parent,
         const QJsonObject& json_setting = json_array[i].toObject();
 
         const std::string key = ReadStringValue(json_setting, "key");
+        if (this->key == "VK_LAYER_KHRONOS_validation" && this->api_version > Version(1, 3, 261)) {
+            if (key == "enables") {
+                continue;
+            }
+            if (key == "disables") {
+                continue;
+            }
+        }
+
         const std::string desc = ReadStringValue(json_setting, "description");
         const SettingType type = GetSettingType(ReadStringValue(json_setting, "type").c_str());
+        if (type == SETTING_INVALID) {
+            continue;
+        }
+
+        SettingView view = SETTING_VIEW_STANDARD;
+        if (json_setting.value("view") != QJsonValue::Undefined) {
+            view = GetSettingView(ReadStringValue(json_setting, "view").c_str());
+        } else if (parent != nullptr) {
+            view = parent->view;
+        }
+        if (view == SETTING_VIEW_HIDDEN) {
+            continue;
+        }
+
         SettingMeta* setting_meta = Instantiate(settings, key, type);
         setting_meta->platform_flags = parent == nullptr ? this->platforms : parent->platform_flags;
-        setting_meta->status = parent == nullptr ? this->status : parent->status;
-        if (parent != nullptr) setting_meta->view = parent->view;
+        setting_meta->status = parent == nullptr ? STATUS_STABLE : parent->status;
+        setting_meta->view = view;
 
         LoadMetaHeader(*setting_meta, json_setting);
         if (json_setting.value("env") != QJsonValue::Undefined) {
@@ -539,7 +478,7 @@ void Layer::AddSettingsSet(SettingMetaSet& settings, const SettingMeta* parent,
         if (setting_meta->type == SETTING_LOAD_FILE) {
             const SettingMetaFileLoad& setting_file = static_cast<const SettingMetaFileLoad&>(*setting_meta);
             if (setting_file.format == "PROFILE") {
-                const std::string& value = ReplaceBuiltInVariable(setting_file.default_value);
+                const std::string& value = setting_file.default_value.AbsolutePath();
                 const QJsonDocument& doc = ParseJsonFile(value.c_str());
 
                 if (!doc.isNull() && !doc.isEmpty()) {
@@ -580,7 +519,10 @@ void Layer::AddSettingData(SettingDataSet& settings_data, const QJsonValue& json
 
     const std::string& key = ReadStringValue(json_setting_object, "key");
 
-    SettingMeta* setting_meta = FindSetting(this->settings, key.c_str());
+    SettingMeta* setting_meta = ::FindSetting(this->settings, key.c_str());
+    if (setting_meta == nullptr) {
+        return;
+    }
     assert(setting_meta);
 
     SettingData* setting_data = setting_meta->Instantiate();
