@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2021 Valve Corporation
- * Copyright (c) 2020-2021 LunarG, Inc.
+ * Copyright (c) 2020-2025 Valve Corporation
+ * Copyright (c) 2020-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,10 +32,12 @@
 
 #include <regex>
 
-inline SettingMetaString* InstantiateString(Layer& layer, const std::string& key) {
+static SettingMetaString* InstantiateString(Layer& layer, const std::string& key) {
     return static_cast<SettingMetaString*>(layer.Instantiate(layer.settings, key, SETTING_STRING));
 }
 
+static std::map<Path, LayerStatus> Dummy() { return std::map<Path, LayerStatus>(); }
+
 TEST(test_layer, collect_settings) {
     Layer layer;
 
@@ -58,44 +60,52 @@ TEST(test_layer, collect_settings) {
 
 TEST(test_layer, load_header_overridden) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_00.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_00.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_STREQ("VK_LAYER_LUNARG_test_00", layer.key.c_str());
-    EXPECT_STREQ(".\\VkLayer_test.dll", layer.binary_path.c_str());
+    EXPECT_STREQ(Path(".\\VkLayer_test.dll").RelativePath().c_str(), layer.binary_path.RelativePath().c_str());
     EXPECT_EQ(Version(1, 2, 170), layer.api_version);
     EXPECT_STREQ("Build 76", layer.implementation_version.c_str());
     EXPECT_STREQ("test layer", layer.description.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.platforms);
     EXPECT_EQ(STATUS_BETA, layer.status);
-    EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html", layer.url.c_str());
+    EXPECT_EQ(true, layer.disable_env.empty());
+    EXPECT_EQ(true, layer.enable_env.empty());
+    EXPECT_EQ(true, layer.enable_value.empty());
+    EXPECT_EQ(false, layer.is_32bits);
+    EXPECT_EQ(true, layer.enabled);
+    EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html", layer.url.RelativePath(false).c_str());
     EXPECT_TRUE(layer.settings.empty());
     EXPECT_TRUE(layer.presets.empty());
 }
 
 TEST(test_layer, load_header_default) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_01.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_01.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_STREQ("VK_LAYER_LUNARG_test_01", layer.key.c_str());
-    EXPECT_STREQ(".\\VkLayer_test.dll", layer.binary_path.c_str());
+    EXPECT_STREQ(Path(".\\VkLayer_test.dll").RelativePath().c_str(), layer.binary_path.RelativePath().c_str());
     EXPECT_EQ(Version(1, 2, 170), layer.api_version);
     EXPECT_STREQ("Build 76", layer.implementation_version.c_str());
     EXPECT_STREQ("test layer", layer.description.c_str());
     EXPECT_EQ(PLATFORM_DESKTOP_BIT, layer.platforms);
     EXPECT_EQ(STATUS_STABLE, layer.status);
-    EXPECT_TRUE(layer.url.empty());
+    EXPECT_TRUE(layer.url.Empty());
     EXPECT_EQ(0, layer.settings.size());
     EXPECT_EQ(0, layer.presets.size());
 }
 
 TEST(test_layer, load_header_override) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_02.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_02.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, layer.platforms);
@@ -106,8 +116,9 @@ TEST(test_layer, load_header_override) {
 
 TEST(test_layer, load_setting_interit) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_03.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_03.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, layer.platforms);
@@ -117,7 +128,7 @@ TEST(test_layer, load_setting_interit) {
 
     EXPECT_STREQ("int_inherit", layer.settings[0]->key.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, layer.settings[0]->platform_flags);
-    EXPECT_EQ(STATUS_BETA, layer.settings[0]->status);
+    EXPECT_EQ(STATUS_STABLE, layer.settings[0]->status);
     EXPECT_EQ(SETTING_VIEW_STANDARD, layer.settings[0]->view);
 
     EXPECT_STREQ("int_override", layer.settings[1]->key.c_str());
@@ -128,8 +139,9 @@ TEST(test_layer, load_setting_interit) {
 
 TEST(test_layer, load_preset_interit) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_04.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_04.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, layer.platforms);
@@ -139,39 +151,48 @@ TEST(test_layer, load_preset_interit) {
 
     EXPECT_STREQ("Preset Inherit", layer.presets[0].label.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, layer.presets[0].platform_flags);
-    EXPECT_EQ(STATUS_BETA, layer.presets[0].status);
+    EXPECT_EQ(STATUS_STABLE, layer.presets[0].status);
 
     EXPECT_STREQ("Preset Override", layer.presets[1].label.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.presets[1].platform_flags);
     EXPECT_EQ(STATUS_ALPHA, layer.presets[1].status);
+
+    const LayerLoadStatus reloaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_04.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(reloaded, LAYER_LOAD_ADDED);
+    EXPECT_EQ(1, layer.settings.size());
+    EXPECT_EQ(2, layer.presets.size());
 }
 
 TEST(test_layer, load_setting_children_interit) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_05.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_05.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_EQ(0, layer.presets.size());
     EXPECT_EQ(1, layer.settings.size());
-    EXPECT_EQ(2, layer.settings[0]->children.size());
-    EXPECT_EQ(3, CountSettings(layer.settings));
+    EXPECT_EQ(1, layer.settings[0]->children.size());
+    EXPECT_EQ(2, CountSettings(layer.settings));
 
     EXPECT_STREQ("int_inherit", layer.settings[0]->children[0]->key.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.settings[0]->children[0]->platform_flags);
     EXPECT_EQ(STATUS_BETA, layer.settings[0]->children[0]->status);
     EXPECT_EQ(SETTING_VIEW_ADVANCED, layer.settings[0]->children[0]->view);
-
+    /* Hidden settings are not loaded
     EXPECT_STREQ("int_override", layer.settings[0]->children[1]->key.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT, layer.settings[0]->children[1]->platform_flags);
     EXPECT_EQ(STATUS_ALPHA, layer.settings[0]->children[1]->status);
     EXPECT_EQ(SETTING_VIEW_HIDDEN, layer.settings[0]->children[1]->view);
+    */
 }
 
 TEST(test_layer, load_setting_enum_interit) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_test_06.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_06.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT | PLATFORM_MACOS_BIT | PLATFORM_ANDROID_BIT, layer.platforms);
@@ -185,7 +206,7 @@ TEST(test_layer, load_setting_enum_interit) {
     EXPECT_STREQ("value0", setting_inherit->enum_values[0].key.c_str());
     EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT | PLATFORM_MACOS_BIT | PLATFORM_ANDROID_BIT,
               setting_inherit->enum_values[0].platform_flags);
-    EXPECT_EQ(STATUS_BETA, setting_inherit->enum_values[0].status);
+    EXPECT_EQ(STATUS_STABLE, setting_inherit->enum_values[0].status);
     EXPECT_EQ(SETTING_VIEW_STANDARD, setting_inherit->enum_values[0].view);
 
     EXPECT_STREQ("value1", setting_inherit->enum_values[1].key.c_str());
@@ -210,28 +231,100 @@ TEST(test_layer, load_setting_enum_interit) {
     EXPECT_EQ(SETTING_VIEW_HIDDEN, setting_override->enum_values[1].view);
 }
 
+TEST(test_layer, load_setting_missing) {
+    Layer layer;
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_07.json", LAYER_TYPE_IMPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
+
+    EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
+    EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, layer.platforms);
+    EXPECT_EQ(STATUS_BETA, layer.status);
+    EXPECT_EQ(1, layer.settings.size());
+    EXPECT_EQ(1, layer.presets.size());
+
+    LayerControl layer_controlA = layer.GetActualControl();
+    EXPECT_EQ(layer_controlA, LAYER_CONTROL_ON);
+
+    const LayerLoadStatus reloaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_07.json", LAYER_TYPE_IMPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(1, layer.settings.size());
+    EXPECT_EQ(1, layer.presets.size());
+}
+
+TEST(test_layer, load_env_variable) {
+    Layer layer;
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_test_08.json", LAYER_TYPE_IMPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
+
+    EXPECT_EQ(Version(1, 2, 0), layer.file_format_version);
+    EXPECT_STREQ("VK_LAYER_LUNARG_test_08", layer.key.c_str());
+    EXPECT_STREQ(Path(".\\VkLayer_test.dll").RelativePath().c_str(), layer.binary_path.RelativePath().c_str());
+    EXPECT_EQ(Version(1, 2, 170), layer.api_version);
+    EXPECT_STREQ("Build 76", layer.implementation_version.c_str());
+    EXPECT_STREQ("test layer", layer.description.c_str());
+    EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.platforms);
+    EXPECT_EQ(STATUS_BETA, layer.status);
+    EXPECT_STREQ("VK_LAYER_TEST08_DISABLE", layer.disable_env.c_str());
+    EXPECT_STREQ("VK_LAYER_TEST08_ENABLE", layer.enable_env.c_str());
+    EXPECT_STREQ("1", layer.enable_value.c_str());
+    EXPECT_EQ(false, layer.is_32bits);
+    EXPECT_EQ(true, layer.enabled);
+    EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html", layer.url.RelativePath(false).c_str());
+    EXPECT_TRUE(layer.settings.empty());
+    EXPECT_TRUE(layer.presets.empty());
+
+    LayerControl layer_controlA = layer.GetActualControl();
+    EXPECT_EQ(layer_controlA, LAYER_CONTROL_OFF);
+
+    qputenv("VK_LAYER_TEST08_DISABLE", "1");
+    LayerControl layer_controlB = layer.GetActualControl();
+    EXPECT_EQ(layer_controlB, LAYER_CONTROL_OFF);
+    qunsetenv("VK_LAYER_TEST08_DISABLE");
+
+    qputenv("VK_LAYER_TEST08_ENABLE", "0");
+    LayerControl layer_controlC = layer.GetActualControl();
+    EXPECT_EQ(layer_controlC, LAYER_CONTROL_OFF);
+    qunsetenv("VK_LAYER_TEST08_ENABLE");
+
+    qputenv("VK_LAYER_TEST08_ENABLE", "1");
+    LayerControl layer_controlD = layer.GetActualControl();
+    EXPECT_EQ(layer_controlD, LAYER_CONTROL_ON);
+    qunsetenv("VK_LAYER_TEST08_ENABLE");
+
+    qputenv("VK_LAYER_TEST08_DISABLE", "1");
+    qputenv("VK_LAYER_TEST08_ENABLE", "1");
+    LayerControl layer_controlE = layer.GetActualControl();
+    EXPECT_EQ(layer_controlE, LAYER_CONTROL_OFF);
+    qunsetenv("VK_LAYER_TEST08_DISABLE");
+    qunsetenv("VK_LAYER_TEST08_ENABLE");
+}
+
 TEST(test_layer, load_1_1_0_header) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_reference_1_1_0.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_reference_1_1_0.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     EXPECT_EQ(Version(1, 1, 0), layer.file_format_version);
     EXPECT_STREQ("VK_LAYER_LUNARG_reference_1_1_0", layer.key.c_str());
-    EXPECT_STREQ(".\\VkLayer_reference.dll", layer.binary_path.c_str());
+    EXPECT_STREQ(Path(".\\VkLayer_reference.dll").RelativePath().c_str(), layer.binary_path.RelativePath().c_str());
     EXPECT_EQ(Version(1, 2, 162), layer.api_version);
     EXPECT_STREQ("Build 75", layer.implementation_version.c_str());
     EXPECT_STREQ("reference layer", layer.description.c_str());
     EXPECT_EQ(PLATFORM_DESKTOP_BIT, layer.platforms);
     EXPECT_EQ(STATUS_STABLE, layer.status);
-    EXPECT_TRUE(layer.url.empty());
+    EXPECT_TRUE(layer.url.Empty());
     EXPECT_TRUE(layer.settings.empty());
     EXPECT_TRUE(layer.presets.empty());
 }
 
 TEST(test_layer, load_1_2_0_preset_and_setting_type) {
     Layer layer;
-    const bool load_loaded = layer.Load(std::vector<Layer>(), ":/VK_LAYER_LUNARG_reference_1_2_0.json", LAYER_TYPE_EXPLICIT);
-    ASSERT_TRUE(load_loaded);
+    const LayerLoadStatus load_loaded =
+        layer.Load(":/layers/VK_LAYER_LUNARG_reference_1_2_0.json", LAYER_TYPE_EXPLICIT, false, Dummy(), CONFIGURATOR_MODE_CMD);
+    EXPECT_EQ(load_loaded, LAYER_LOAD_ADDED);
 
     // Preset Enum
     {
@@ -277,11 +370,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
     {
         const std::size_t index = 2;
 
-        const SettingDataFileLoad* setting_only =
-            static_cast<const SettingDataFileLoad*>(FindSetting(layer.presets[index].settings, "string_required_only"));
+        const SettingDataString* setting_only =
+            static_cast<const SettingDataString*>(FindSetting(layer.presets[index].settings, "string_required_only"));
         ASSERT_TRUE(setting_only);
-        const SettingDataFileLoad* setting_opt =
-            static_cast<const SettingDataFileLoad*>(FindSetting(layer.presets[index].settings, "string_with_optional"));
+        const SettingDataString* setting_opt =
+            static_cast<const SettingDataString*>(FindSetting(layer.presets[index].settings, "string_with_optional"));
         ASSERT_TRUE(setting_opt);
 
         EXPECT_STREQ("Preset String", layer.presets[index].label.c_str());
@@ -321,8 +414,8 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_STREQ("Description Load File", layer.presets[index].description.c_str());
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.presets[index].platform_flags);
         EXPECT_EQ(STATUS_DEPRECATED, layer.presets[index].status);
-        EXPECT_STREQ("./text.log", setting_only->value.c_str());
-        EXPECT_STREQ("./text.log", setting_opt->value.c_str());
+        EXPECT_STREQ(Path("./text.log").RelativePath().c_str(), setting_only->value.RelativePath().c_str());
+        EXPECT_STREQ(Path("./text.log").RelativePath().c_str(), setting_opt->value.RelativePath().c_str());
     }
 
     // Preset Load Folder
@@ -340,8 +433,8 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_STREQ("Description Load Folder", layer.presets[index].description.c_str());
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.presets[index].platform_flags);
         EXPECT_EQ(STATUS_DEPRECATED, layer.presets[index].status);
-        EXPECT_STREQ("./text", setting_only->value.c_str());
-        EXPECT_STREQ("./text", setting_opt->value.c_str());
+        EXPECT_STREQ(Path("./text").RelativePath().c_str(), setting_only->value.RelativePath().c_str());
+        EXPECT_STREQ(Path("./text").RelativePath().c_str(), setting_opt->value.RelativePath().c_str());
     }
 
     // Preset Save File
@@ -359,8 +452,8 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_STREQ("Description Save File", layer.presets[index].description.c_str());
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.presets[index].platform_flags);
         EXPECT_EQ(STATUS_DEPRECATED, layer.presets[index].status);
-        EXPECT_STREQ("./text.log", setting_only->value.c_str());
-        EXPECT_STREQ("./text.log", setting_opt->value.c_str());
+        EXPECT_STREQ(Path("./text.log").RelativePath().c_str(), setting_only->value.RelativePath().c_str());
+        EXPECT_STREQ(Path("./text.log").RelativePath().c_str(), setting_opt->value.RelativePath().c_str());
     }
 
     // Preset Save Folder
@@ -378,8 +471,8 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_STREQ("Description Save Folder", layer.presets[index].description.c_str());
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_MACOS_BIT, layer.presets[index].platform_flags);
         EXPECT_EQ(STATUS_DEPRECATED, layer.presets[index].status);
-        EXPECT_STREQ("./text", setting_only->value.c_str());
-        EXPECT_STREQ("./text", setting_opt->value.c_str());
+        EXPECT_STREQ(Path("./text").RelativePath().c_str(), setting_only->value.RelativePath().c_str());
+        EXPECT_STREQ(Path("./text").RelativePath().c_str(), setting_opt->value.RelativePath().c_str());
     }
 
     // Preset int
@@ -448,11 +541,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("enum_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_ENUM_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_ENUM, setting_meta->type);
         EXPECT_STREQ("enum", setting_meta->label.c_str());
         EXPECT_STREQ("enum case", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -489,7 +582,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_ENUM, setting_meta->type);
         EXPECT_STREQ("enum", setting_meta->label.c_str());
         EXPECT_STREQ("enum case", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#enum", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#enum", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT, setting_meta->platform_flags);
@@ -499,7 +592,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         value0.key = "value0";
         value0.label = "Value0";
         value0.description = "My value0";
-        value0.url = "https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#value0";
+        value0.url = "${LUNARG_SDK}/layer_dummy.html#value0";
         value0.status = STATUS_STABLE;
         value0.view = SETTING_VIEW_HIDDEN;
         value0.platform_flags = PLATFORM_DESKTOP_BIT;
@@ -509,7 +602,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         value1.key = "value1";
         value1.label = "Value1";
         value1.description = "My value1";
-        value1.url = "https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#value1";
+        value1.url = "${LUNARG_SDK}/layer_dummy.html#value1";
         value1.status = STATUS_BETA;
         value1.view = SETTING_VIEW_ADVANCED;
         value1.platform_flags = PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT;
@@ -519,7 +612,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         value2.key = "value2";
         value2.label = "Value2";
         value2.description = "My value2";
-        value2.url = "https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#value2";
+        value2.url = "${LUNARG_SDK}/layer_dummy.html#value2";
         value2.status = STATUS_ALPHA;
         value2.view = SETTING_VIEW_STANDARD;
         value2.platform_flags = PLATFORM_WINDOWS_BIT;
@@ -534,11 +627,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("flags_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_FLAGS_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_FLAGS, setting_meta->type);
         EXPECT_STREQ("flags", setting_meta->label.c_str());
         EXPECT_STREQ("flags case", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -576,7 +669,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_FLAGS, setting_meta->type);
         EXPECT_STREQ("flags", setting_meta->label.c_str());
         EXPECT_STREQ("flags case", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#flags", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#flags", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
@@ -586,7 +679,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         value0.key = "flag0";
         value0.label = "Flag0";
         value0.description = "My flag0";
-        value0.url = "https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#flag0";
+        value0.url = Path("${LUNARG_SDK}/layer_dummy.html#flag0", false);
         value0.status = STATUS_STABLE;
         value0.view = SETTING_VIEW_STANDARD;
         value0.platform_flags = PLATFORM_DESKTOP_BIT;
@@ -596,7 +689,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         value1.key = "flag1";
         value1.label = "Flag1";
         value1.description = "My flag1";
-        value1.url = "https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#flag1";
+        value1.url = Path("${LUNARG_SDK}/layer_dummy.html#flag1", false);
         value1.status = STATUS_BETA;
         value1.view = SETTING_VIEW_ADVANCED;
         value1.platform_flags = PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT;
@@ -606,7 +699,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         value2.key = "flag2";
         value2.label = "Flag2";
         value2.description = "My flag2";
-        value2.url = "https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#flag2";
+        value2.url = Path("${LUNARG_SDK}/layer_dummy.html#flag2", false);
         value2.status = STATUS_ALPHA;
         value2.view = SETTING_VIEW_HIDDEN;
         value2.platform_flags = PLATFORM_WINDOWS_BIT;
@@ -622,11 +715,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("string_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_STRING_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_STRING, setting_meta->type);
         EXPECT_STREQ("String", setting_meta->label.c_str());
         EXPECT_STREQ("string", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -644,7 +737,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_STRING, setting_meta->type);
         EXPECT_STREQ("String", setting_meta->label.c_str());
         EXPECT_STREQ("string", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#string", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#string", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
@@ -658,11 +751,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("bool_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_BOOL_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_BOOL, setting_meta->type);
         EXPECT_STREQ("bool", setting_meta->label.c_str());
         EXPECT_STREQ("true or false", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -680,7 +773,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_BOOL, setting_meta->type);
         EXPECT_STREQ("bool", setting_meta->label.c_str());
         EXPECT_STREQ("true or false", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#bool", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#bool", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
@@ -695,17 +788,17 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("load_file_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_LOAD_FILE_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_LOAD_FILE, setting_meta->type);
         EXPECT_STREQ("Load file", setting_meta->label.c_str());
         EXPECT_STREQ("Load file path", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
         EXPECT_TRUE(setting_meta->filter.empty());
 
-        EXPECT_STREQ("./test.txt", setting_meta->default_value.c_str());
+        EXPECT_STREQ(setting_meta->default_value.RelativePath().c_str(), Path("./test.txt").RelativePath().c_str());
     }
 
     // Load File With Optional
@@ -719,13 +812,13 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_LOAD_FILE, setting_meta->type);
         EXPECT_STREQ("Load file", setting_meta->label.c_str());
         EXPECT_STREQ("Load file path", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#load_file", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#load_file", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
         EXPECT_STREQ("*.txt", setting_meta->filter.c_str());
 
-        EXPECT_STREQ("./test.txt", setting_meta->default_value.c_str());
+        EXPECT_STREQ(setting_meta->default_value.RelativePath().c_str(), Path("./test.txt").RelativePath().c_str());
     }
 
     // Save File Required Only
@@ -735,17 +828,17 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("save_file_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_SAVE_FILE_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_SAVE_FILE, setting_meta->type);
         EXPECT_STREQ("Save file", setting_meta->label.c_str());
         EXPECT_STREQ("Save file path", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
         EXPECT_TRUE(setting_meta->filter.empty());
 
-        EXPECT_STREQ("./test.json", setting_meta->default_value.c_str());
+        EXPECT_STREQ(setting_meta->default_value.RelativePath().c_str(), Path("./test.json").RelativePath().c_str());
     }
 
     // Save File With Optional
@@ -759,13 +852,13 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_SAVE_FILE, setting_meta->type);
         EXPECT_STREQ("Save file", setting_meta->label.c_str());
         EXPECT_STREQ("Save file path", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#save_file", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#save_file", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
         EXPECT_STREQ("*.json", setting_meta->filter.c_str());
 
-        EXPECT_STREQ("./test.json", setting_meta->default_value.c_str());
+        EXPECT_STREQ(setting_meta->default_value.RelativePath().c_str(), Path("./test.json").RelativePath().c_str());
     }
 
     // Save Folder Required Only
@@ -775,16 +868,16 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("save_folder_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_SAVE_FOLDER_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_SAVE_FOLDER, setting_meta->type);
         EXPECT_STREQ("Save folder", setting_meta->label.c_str());
         EXPECT_STREQ("Save folder path", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
 
-        EXPECT_STREQ("./test", setting_meta->default_value.c_str());
+        EXPECT_STREQ(setting_meta->default_value.RelativePath().c_str(), Path("./test").RelativePath().c_str());
     }
 
     // Save Folder With Optional
@@ -798,12 +891,12 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_SAVE_FOLDER, setting_meta->type);
         EXPECT_STREQ("Save folder", setting_meta->label.c_str());
         EXPECT_STREQ("Save folder path", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#save_folder", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#save_folder", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
 
-        EXPECT_STREQ("./test", setting_meta->default_value.c_str());
+        EXPECT_STREQ(setting_meta->default_value.RelativePath().c_str(), Path("./test").RelativePath().c_str());
     }
 
     // Int Required Only
@@ -812,11 +905,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("int_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_INT_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_INT, setting_meta->type);
         EXPECT_STREQ("Integer", setting_meta->label.c_str());
         EXPECT_STREQ("Integer Description", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -837,7 +930,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_INT, setting_meta->type);
         EXPECT_STREQ("Integer", setting_meta->label.c_str());
         EXPECT_STREQ("Integer Description", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#int", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#int", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
@@ -854,11 +947,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("frames_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_FRAMES_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_FRAMES, setting_meta->type);
         EXPECT_STREQ("Frames", setting_meta->label.c_str());
         EXPECT_STREQ("Frames Description", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -876,7 +969,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_FRAMES, setting_meta->type);
         EXPECT_STREQ("Frames", setting_meta->label.c_str());
         EXPECT_STREQ("Frames Description", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#frames", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#frames", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
@@ -891,11 +984,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("list_required_only", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_LIST_REQUIRED_ONLY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_LIST, setting_meta->type);
         EXPECT_STREQ("List", setting_meta->label.c_str());
         EXPECT_STREQ("List description", setting_meta->description.c_str());
-        EXPECT_TRUE(setting_meta->url.empty());
+        EXPECT_TRUE(setting_meta->url.Empty());
         EXPECT_EQ(STATUS_STABLE, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_STANDARD, setting_meta->view);
         EXPECT_EQ(PLATFORM_DESKTOP_BIT, setting_meta->platform_flags);
@@ -937,7 +1030,7 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         EXPECT_EQ(SETTING_LIST, setting_meta->type);
         EXPECT_STREQ("List", setting_meta->label.c_str());
         EXPECT_STREQ("List description", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#list", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#list", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
@@ -981,11 +1074,11 @@ TEST(test_layer, load_1_2_0_preset_and_setting_type) {
         ASSERT_TRUE(setting_meta != nullptr);
 
         EXPECT_STREQ("list_empty", setting_meta->key.c_str());
-        EXPECT_STREQ("VK_LUNARG_REFERENCE_1_2_0_LIST_EMPTY", setting_meta->env.c_str());
+        EXPECT_TRUE(setting_meta->env.empty());
         EXPECT_EQ(SETTING_LIST, setting_meta->type);
         EXPECT_STREQ("List", setting_meta->label.c_str());
         EXPECT_STREQ("List description", setting_meta->description.c_str());
-        EXPECT_STREQ("https://vulkan.lunarg.com/doc/sdk/latest/windows/layer_dummy.html#list", setting_meta->url.c_str());
+        EXPECT_STREQ("${LUNARG_SDK}/layer_dummy.html#list", setting_meta->url.RelativePath(false).c_str());
         EXPECT_EQ(STATUS_BETA, setting_meta->status);
         EXPECT_EQ(SETTING_VIEW_ADVANCED, setting_meta->view);
         EXPECT_EQ(PLATFORM_WINDOWS_BIT | PLATFORM_LINUX_BIT, setting_meta->platform_flags);
