@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2024 Valve Corporation
- * Copyright (c) 2020-2024 LunarG, Inc.
+ * Copyright (c) 2020-2025 Valve Corporation
+ * Copyright (c) 2020-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@
  */
 
 #include "../util.h"
-#include "../platform.h"
+#include "../type_platform.h"
 
 #include <array>
 
@@ -27,57 +27,33 @@
 
 #include <gtest/gtest.h>
 
-TEST(test_util, countof_int_2) {
-    const int test_data[]{8, 9};
-    static_assert(countof(test_data) == 2, "countof for 2 ints is broken");
+template <typename T>
+T* FindByKey(std::vector<T>& container, const char* key) {
+    assert(key != nullptr);
+    assert(std::strcmp(key, "") != 0);
 
-    EXPECT_EQ(2, countof(test_data));
+    for (std::size_t i = 0, n = container.size(); i < n; ++i) {
+        if (container[i].key == key) return &container[i];
+    }
+
+    return nullptr;
 }
 
-TEST(test_util, countof_int_1) {
-    const int test_data[]{7};
-    static_assert(countof(test_data) == 1, "countof for 1 int is broken");
+template <typename T>
+const T* FindByKey(const std::vector<T>& container, const char* key) {
+    assert(key != nullptr);
+    assert(std::strcmp(key, "") != 0);
 
-    EXPECT_EQ(1, countof(test_data));
+    for (std::size_t i = 0, n = container.size(); i < n; ++i) {
+        if (container[i].key == key) return &container[i];
+    }
+
+    return nullptr;
 }
 
-TEST(test_util, countof_cstring_3) {
-    const char* test_data[]{"GNI", "GNA", "GNE"};
-    static_assert(countof(test_data) == 3, "countof for cstring is broken");
-
-    EXPECT_EQ(3, countof(test_data));
-}
-
-TEST(test_util, countof_string_3) {
-    const std::string test_data[]{"GNI", "GNA", "GNE"};
-    static_assert(countof(test_data) == 3, "countof for string is broken");
-
-    EXPECT_EQ(3, countof(test_data));
-}
-
-TEST(test_util, countof_array_2) {
-    const std::array<int, 2> test_data{6, 7};
-    static_assert(countof(test_data) == 2, "countof for array is broken");
-
-    EXPECT_EQ(2, countof(test_data));
-}
-
-TEST(test_util, countof_array_3) {
-    const std::array<std::string, 3> test_data{"GNI", "GNA", "GNE"};
-
-    EXPECT_EQ(3, countof(test_data));
-}
-
-TEST(test_util, countof_vector_2) {
-    const std::vector<int> test_data{6, 7};
-
-    EXPECT_EQ(2, countof(test_data));
-}
-
-TEST(test_util, countof_vector_3) {
-    const std::vector<std::string> test_data{"GNI", "GNA", "GNE"};
-
-    EXPECT_EQ(3, countof(test_data));
+template <typename T>
+bool IsFound(const std::vector<T>& container, const char* key) {
+    return FindByKey(container, key) != nullptr;
 }
 
 TEST(test_util, format_int_1) { EXPECT_EQ("Test 1", format("Test %d", 1)); }
@@ -155,29 +131,83 @@ TEST(test_util, trim_whitepace) {
     }
 }
 
-TEST(test_util, split_space) {
-    std::vector<std::string> merged_strings;
-    merged_strings.push_back(" \" gna \" \" gni \" \" gne gnu \" \" gny \" \" gno \" ");
-    merged_strings.push_back("gna gni \"gne gnu\" gny gno");
-    merged_strings.push_back("gna gni\"gne gnu\"gny gno");
-    merged_strings.push_back(" gna gni \"gne gnu\" gny gno ");
-    merged_strings.push_back(" \"gna\" \"gni\" \"gne gnu\" \"gny\" \"gno\" ");
-    merged_strings.push_back("\"gna\"\"gni\"\"gne gnu\"\"gny\"\"gno\"");
+TEST(test_util, trim_surrounding_whitepace) {
+    std::vector<std::string> strings;
+    strings.push_back("-o profile.json");
+    strings.push_back(" -o profile.json ");
+    strings.push_back("\"-o profile.json\"");
 
-    for (std::size_t i = 0, n = merged_strings.size(); i < n; ++i) {
-        const std::string merge = merged_strings[i];
-        const std::vector<std::string> split = SplitSpace(merge);
+    for (std::size_t i = 0, n = strings.size(); i < n; ++i) {
+        std::string trimed_string = TrimSurroundingWhitespace(strings[i]);
 
-        EXPECT_STREQ("gna", split[0].c_str());
-        EXPECT_STREQ("gni", split[1].c_str());
-        EXPECT_STREQ("gne gnu", split[2].c_str());
-        EXPECT_STREQ("gny", split[3].c_str());
-        EXPECT_STREQ("gno", split[4].c_str());
-
-        EXPECT_EQ(5, split.size());
+        EXPECT_STREQ("-o profile.json", trimed_string.c_str());
     }
 }
 
+TEST(test_util, split_arg_default) {
+    const std::string source_arg = "--argA --argB=valueB \"--argC=value C\" --argD=\"value D\"";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(4, split_arg.size());
+    EXPECT_STREQ("--argA", split_arg[0].c_str());
+    EXPECT_STREQ("--argB=valueB", split_arg[1].c_str());
+    EXPECT_STREQ("\"--argC=value C\"", split_arg[2].c_str());
+    EXPECT_STREQ("--argD=\"value D\"", split_arg[3].c_str());
+}
+
+TEST(test_util, split_single) {
+    const std::string source_arg = "--argB=valueB";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(1, split_arg.size());
+    EXPECT_STREQ("--argB=valueB", split_arg[0].c_str());
+}
+
+TEST(test_util, split_single_quote) {
+    const std::string source_arg = "\"--argC=value C\"";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(1, split_arg.size());
+    EXPECT_STREQ("\"--argC=value C\"", split_arg[0].c_str());
+}
+
+TEST(test_util, split_no_space) {
+    const std::string source_arg = "\"--argC=valueC\"";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(1, split_arg.size());
+    EXPECT_STREQ("\"--argC=valueC\"", split_arg[0].c_str());
+}
+
+TEST(test_util, split_single_quote_value) {
+    const std::string source_arg = "--argD=\"value D\"";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(1, split_arg.size());
+    EXPECT_STREQ("--argD=\"value D\"", split_arg[0].c_str());
+}
+
+TEST(test_util, split_no_quote) {
+    const std::string source_arg = "--argA --argB=valueB";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(2, split_arg.size());
+    EXPECT_STREQ("--argA", split_arg[0].c_str());
+    EXPECT_STREQ("--argB=valueB", split_arg[1].c_str());
+}
+
+TEST(test_util, split_arg_quote) {
+    const std::string source_arg = "\"--argC=value C\" --argD=\"value D\"";
+    const std::vector<std::string> split_arg = SplitSpace(source_arg);
+    EXPECT_EQ(2, split_arg.size());
+    EXPECT_STREQ("\"--argC=value C\"", split_arg[0].c_str());
+    EXPECT_STREQ("--argD=\"value D\"", split_arg[1].c_str());
+}
+
+TEST(test_util, split_env) {
+    const std::string source_env = "ENV_A= ENV_B=ValueB \"ENV_C=Value C\" ENV_D=\"Value D\"";
+    const std::vector<std::string> split_env = SplitSpace(source_env);
+    EXPECT_EQ(4, split_env.size());
+    EXPECT_STREQ("ENV_A=", split_env[0].c_str());
+    EXPECT_STREQ("ENV_B=ValueB", split_env[1].c_str());
+    EXPECT_STREQ("\"ENV_C=Value C\"", split_env[2].c_str());
+    EXPECT_STREQ("ENV_D=\"Value D\"", split_env[3].c_str());
+}
+
 TEST(test_util, split_merge_delimiter) {
     std::vector<std::string> delimiters;
     delimiters.push_back(",");
