@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2024 Valve Corporation
- * Copyright (c) 2020-2024 LunarG, Inc.
+ * Copyright (c) 2020-2025 Valve Corporation
+ * Copyright (c) 2020-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,7 +20,10 @@
  */
 
 #include "util.h"
-#include "platform.h"
+#include "type_platform.h"
+
+#include <QString>
+#include <QStringList>
 
 #include <cstddef>
 #include <cstring>
@@ -28,11 +31,15 @@
 #include <cstdarg>
 #include <cctype>
 
-#include <QString>
-#include <QStringList>
-
 #include <cctype>
 #include <regex>
+#include <set>
+
+const char* GetToken(ParseSource type) {
+    static const char* table[] = {",", VKC_ENV == VKC_ENV_WIN32 ? ";" : ":"};
+
+    return table[type];
+}
 
 std::string format(const char* message, ...) {
     std::size_t const STRING_BUFFER(4096);
@@ -44,18 +51,31 @@ std::string format(const char* message, ...) {
     va_list list;
 
     va_start(list, message);
-    vsprintf(buffer, message, list);
+    vsnprintf(buffer, sizeof(buffer), message, list);
     va_end(list);
 
     return buffer;
 }
 
+std::string FormatNvidia(uint32_t driverVersion) {
+    return format("%d.%d.%d.%d", (driverVersion >> 22) & 0x3ff, (driverVersion >> 14) & 0x0ff, (driverVersion >> 6) & 0x0ff,
+                  driverVersion & 0x003f);
+}
+
+std::string FormatIntelWindows(uint32_t driverVersion) { return format("%d.%d", (driverVersion >> 14), (driverVersion)&0x3fff); }
+
 bool IsFrames(const std::string& s) {
     static const std::regex FRAME_REGEX("^([0-9]+([-][0-9]+){0,2})(,([0-9]+([-][0-9]+){0,2}))*$");
 
     return std::regex_search(s, FRAME_REGEX);
 }
 
+bool IsIndex(const std::string& s) {
+    static const std::regex FRAME_REGEX("^([0-9]*)$");
+
+    return std::regex_search(s, FRAME_REGEX);
+}
+
 bool IsNumber(const std::string& s) {
     static const std::regex FRAME_REGEX("^-?([0-9]*|0x[0-9|a-z|A-Z]*)$");
 
@@ -68,6 +88,18 @@ bool IsFloat(const std::string& s) {
     return std::regex_search(s, FRAME_REGEX);
 }
 
+std::size_t CountChar(const std::string& value, char c) {
+    std::size_t count = 0;
+
+    for (std::size_t i = 0, n = value.size(); i < n; ++i) {
+        if (value[i] == c) {
+            ++count;
+        }
+    }
+
+    return count;
+}
+
 void RemoveString(std::vector<std::string>& list, const std::string& value) {
     std::vector<std::string> new_list;
     new_list.reserve(list.size());
@@ -95,16 +127,23 @@ bool IsStringFound(const std::vector<std::string>& list, const std::string& valu
     return false;
 }
 
-std::string TrimString(const std::string& str, const std::string& whitespace) {
-    const auto strBegin = str.find_first_not_of(whitespace);
+std::string TrimString(const std::string& str, const std::string& whitespaces) {
+    const auto strBegin = str.find_first_not_of(whitespaces);
     if (strBegin == std::string::npos) return "";  // no content
 
-    const auto strEnd = str.find_last_not_of(whitespace);
+    const auto strEnd = str.find_last_not_of(whitespaces);
     const auto strRange = strEnd - strBegin + 1;
 
     return str.substr(strBegin, strRange);
 }
 
+std::string TrimSurroundingWhitespace(const std::string& str, const std::string& whitespaces) {
+    std::string s = str;
+    s.erase(0, s.find_first_not_of(whitespaces));
+    s.erase(s.find_last_not_of(whitespaces) + 1);
+    return s;
+}
+
 std::vector<std::string> TrimEmpty(const std::vector<std::string>& values) {
     std::vector<std::string> results;
 
@@ -140,80 +179,39 @@ std::vector<std::string> Split(const std::string& value, const std::string& deli
     return split_result;
 }
 
-static std::string AddMissingSpaces(const std::string& value) {
-    std::string result;
+std::vector<std::string> SplitSpace(const std::string& parse) {
+    const std::string space = " ";
+    const std::string quote = "\"";
 
-    char prev_value = 0;
-    char next_value = 0;
-    bool found_open = false;
-    for (std::size_t i = 0, n = value.size(); i < n; ++i) {
-        next_value = i < n - 1 ? value[i + 1] : 0;
-        if (!found_open && value[i] == '\"') {
-            if (prev_value != ' ' && (i > 0)) {
-                result += ' ';
-            }
-            result += value[i];
-            found_open = true;
-        } else if (found_open && value[i] == '\"') {
-            result += value[i];
-            if (next_value != ' ' && (i != n - 1)) {
-                result += ' ';
-            }
-            found_open = false;
-        } else {
-            result += value[i];
-        }
-        prev_value = value[i];
-    }
+    std::size_t space_start = 0;
+    std::size_t space_end = parse.find(space, space_start);
+    std::size_t quote_start = parse.find(quote, space_start);
+    std::size_t quote_end = quote_start != std::string::npos ? parse.find(quote, quote_start + quote.length()) : std::string::npos;
 
-    return result;
-}
+    std::vector<std::string> split_result;
 
-std::vector<std::string> SplitSpace(const std::string& value) {
-    const std::string& standardized_value = AddMissingSpaces(value);
-
-    std::vector<std::string> split_result = TrimEmpty(Split(standardized_value, " "));
-
-    std::vector<std::string> merge_result;
-
-    bool found_open = false;
-    bool require_push_back = false;
-    for (std::size_t i = 0, n = split_result.size(); i < n; ++i) {
-        const std::string& split_value = split_result[i];
-
-        const std::string& trim_value = TrimString(split_value, "\"");
-
-        if (split_value == "\"") {
-            if (!found_open) {
-                require_push_back = true;  // new element
-            }
-            found_open = !found_open;
-        } else if (split_value.front() == '\"' && split_value.back() == '\"') {
-            merge_result.push_back(trim_value);
-        } else if (split_value.front() == '\"') {
-            merge_result.push_back(trim_value);
-            found_open = true;
-        } else if (split_value.back() == '\"') {
-            merge_result.back() += " " + trim_value;
-            found_open = false;
-        } else {
-            if (found_open && !merge_result.empty() && !require_push_back) {
-                merge_result.back() += " " + trim_value;
-            } else {
-                merge_result.push_back(trim_value);
-                require_push_back = false;
+    while (space_end != std::string::npos) {
+        if (quote_start != std::string::npos) {
+            // Ignore any "space" between "quote"
+            if (space_end > quote_start && space_end < quote_end) {
+                space_end = parse.find(space, space_end + space.length());
+                continue;
             }
         }
+
+        split_result.push_back(parse.substr(space_start, space_end - space_start));
+        space_start = space_end + space.length();
+        space_end = parse.find(space, space_start);
+        quote_start = parse.find(quote, space_start);
+        quote_end = quote_start != std::string::npos ? parse.find(quote, quote_start + quote.length()) : std::string::npos;
     }
 
-    std::vector<std::string> trim_result;
-    trim_result.reserve(merge_result.size());
-
-    for (std::size_t i = 0, n = merge_result.size(); i < n; ++i) {
-        trim_result.push_back(TrimString(merge_result[i], "\""));
+    const std::string last = parse.substr(space_start);
+    if (!last.empty()) {
+        split_result.push_back(last);
     }
 
-    return trim_result;
+    return split_result;
 }
 
 std::string Merge(const std::vector<std::string>& value, const std::string& delimiter) {
@@ -305,12 +303,19 @@ QStringList ConvertString(const std::vector<std::string>& strings) {
     QStringList string_list;
 
     for (std::size_t i = 0, n = strings.size(); i < n; ++i) {
-        string_list.append(strings[i].c_str());
+        const std::string& value = TrimSurroundingWhitespace(strings[i]);
+        string_list.append(value.c_str());
     }
 
     return string_list;
 }
 
+std::vector<std::string> UniqueStrings(const std::vector<std::string>& strings) {
+    std::set<std::string> uniques(strings.begin(), strings.end());
+    std::vector<std::string> results(uniques.begin(), uniques.end());
+    return results;
+}
+
 std::string ToLowerCase(const std::string& value) {
     std::string result = value;
 
@@ -336,3 +341,31 @@ std::string GetLayerSettingPrefix(const std::string& key) {
     result.remove("VK_LAYER_");
     return ToLowerCase(result.toStdString()) + ".";
 }
+
+static const size_t NOT_FOUND = static_cast<size_t>(-1);
+
+std::size_t ExtractDuplicateNumber(const std::string& name) {
+    const std::size_t name_open = name.find_last_of("(");
+    if (name_open == NOT_FOUND) {
+        return NOT_FOUND;
+    }
+
+    const std::size_t name_close = name.find_last_of(")");
+    if (name_close == NOT_FOUND) {
+        return NOT_FOUND;
+    }
+
+    const std::string number = name.substr(name_open + 1, name_close - (name_open + 1));
+    if (!IsNumber(number)) {
+        return NOT_FOUND;
+    }
+
+    return std::stoi(number);
+}
+
+std::string ExtractDuplicateBaseName(const std::string& name) {
+    assert(ExtractDuplicateNumber(name) != NOT_FOUND);
+    const std::size_t found = name.find_last_of("(");
+    assert(found != NOT_FOUND);
+    return name.substr(0, found - 1);
+}
