@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2024 Valve Corporation
- * Copyright (c) 2020-2024 LunarG, Inc.
+ * Copyright (c) 2020-2025 Valve Corporation
+ * Copyright (c) 2020-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -35,59 +35,25 @@
 #include <vector>
 #include <array>
 
-// Based on https://www.g-truc.net/post-0708.html#menu
-template <typename T, std::size_t N>
-inline constexpr std::size_t countof(T const (&)[N]) noexcept {
-    return N;
-}
+enum ParseSource { PARSE_SETTING = 0, PARSE_ENV_VAR };
 
-template <typename T, std::size_t N>
-inline constexpr std::size_t countof(std::array<T, N> const& data) noexcept {
-    return data.size();
-}
-
-// For C++ container
-template <typename T, typename Alloc, template <typename, typename> class C>
-inline constexpr std::size_t countof(C<T, Alloc> const& data) noexcept {
-    return data.size();
-}
+const char* GetToken(ParseSource type);
 
 std::string format(const char* message, ...);
 
+std::string FormatNvidia(uint32_t driverVersion);
+
+std::string FormatIntelWindows(uint32_t driverVersion);
+
 bool IsFrames(const std::string& s);
 
+bool IsIndex(const std::string& s);
+
 bool IsNumber(const std::string& s);
 
 bool IsFloat(const std::string& s);
 
-template <typename T>
-T* FindByKey(std::vector<T>& container, const char* key) {
-    assert(key != nullptr);
-    assert(std::strcmp(key, "") != 0);
-
-    for (std::size_t i = 0, n = container.size(); i < n; ++i) {
-        if (container[i].key == key) return &container[i];
-    }
-
-    return nullptr;
-}
-
-template <typename T>
-const T* FindByKey(const std::vector<T>& container, const char* key) {
-    assert(key != nullptr);
-    assert(std::strcmp(key, "") != 0);
-
-    for (std::size_t i = 0, n = container.size(); i < n; ++i) {
-        if (container[i].key == key) return &container[i];
-    }
-
-    return nullptr;
-}
-
-template <typename T>
-bool IsFound(const std::vector<T>& container, const char* key) {
-    return FindByKey(container, key) != nullptr;
-}
+std::size_t CountChar(const std::string& value, char c);
 
 // Remove a value if it's present
 void RemoveString(std::vector<std::string>& list, const std::string& value);
@@ -97,7 +63,9 @@ void AppendString(std::vector<std::string>& list, const std::string& value);
 
 bool IsStringFound(const std::vector<std::string>& list, const std::string& value);
 
-std::string TrimString(const std::string& str, const std::string& whitespace = " \t");
+std::string TrimString(const std::string& str, const std::string& whitespaces = " \t");
+
+std::string TrimSurroundingWhitespace(const std::string& str, const std::string& whitespaces = " \"\t\n\r");
 
 std::vector<std::string> Split(const std::string& value, const std::string& delimiter);
 
@@ -109,6 +77,8 @@ std::vector<std::string> ConvertString(const QStringList& string_list);
 
 QStringList ConvertString(const std::vector<std::string>& strings);
 
+std::vector<std::string> UniqueStrings(const std::vector<std::string>& strings);
+
 std::string ToLowerCase(const std::string& value);
 
 std::string ToUpperCase(const std::string& value);
@@ -165,3 +135,14 @@ bool IsValueFound(const std::vector<EnabledNumberOrString>& list, const NumberOr
 QStringList ConvertValues(const std::vector<NumberOrString>& values);
 
 std::string GetLayerSettingPrefix(const std::string& key);
+
+template <typename T>
+std::vector<T> GetVector(const T& value) {
+    std::vector<T> result;
+    result.push_back(value);
+    return result;
+}
+
+std::size_t ExtractDuplicateNumber(const std::string& name);
+
+std::string ExtractDuplicateBaseName(const std::string& name);
